@@ -228,8 +228,6 @@ bool IsErrorPageAutoReloadEnabled() {
 void MaybeCreateAndAddVisitedLinkNavigationThrottle(
     content::NavigationThrottleRegistry& registry) {
   if (!base::FeatureList::IsEnabled(
-          blink::features::kPartitionVisitedLinkDatabase) &&
-      !base::FeatureList::IsEnabled(
           blink::features::kPartitionVisitedLinkDatabaseWithSelfLinks)) {
     return;
   }
@@ -355,8 +353,7 @@ void CreateAndAddChromeThrottlesForNavigation(
 #endif
 
   SupervisedUserGoogleAuthNavigationThrottle::MaybeCreateAndAdd(registry);
-
-  supervised_user::MaybeCreateAndAddClassifyUrlNavigationThrottle(registry);
+  supervised_user::ClassifyUrlNavigationThrottle::MaybeCreateAndAdd(registry);
 
   if (auto* throttle_manager =
           subresource_filter::ContentSubresourceFilterThrottleManager::
