@@ -594,31 +594,31 @@ DownloadItem* GetDownload(content::BrowserContext* context,
 
 // Corresponds to |DownloadFunctions| enumeration in histograms.xml. Please
 // keep these in sync.
-enum DownloadsFunctionName {
-  DOWNLOADS_FUNCTION_DOWNLOAD = 0,
-  DOWNLOADS_FUNCTION_SEARCH = 1,
-  DOWNLOADS_FUNCTION_PAUSE = 2,
-  DOWNLOADS_FUNCTION_RESUME = 3,
-  DOWNLOADS_FUNCTION_CANCEL = 4,
-  DOWNLOADS_FUNCTION_ERASE = 5,
+enum class DownloadsFunctionName {
+  kDownloadsFunctionDownload = 0,
+  kDownloadsFunctionSearch = 1,
+  kDownloadsFunctionPause = 2,
+  kDownloadsFunctionResume = 3,
+  kDownloadsFunctionCancel = 4,
+  kDownloadsFunctionErase = 5,
   // 6 unused
-  DOWNLOADS_FUNCTION_ACCEPT_DANGER = 7,
-  DOWNLOADS_FUNCTION_SHOW = 8,
-  DOWNLOADS_FUNCTION_DRAG = 9,
-  DOWNLOADS_FUNCTION_GET_FILE_ICON = 10,
-  DOWNLOADS_FUNCTION_OPEN = 11,
-  DOWNLOADS_FUNCTION_REMOVE_FILE = 12,
-  DOWNLOADS_FUNCTION_SHOW_DEFAULT_FOLDER = 13,
-  DOWNLOADS_FUNCTION_SET_SHELF_ENABLED = 14,
-  DOWNLOADS_FUNCTION_DETERMINE_FILENAME = 15,
-  DOWNLOADS_FUNCTION_SET_UI_OPTIONS = 16,
+  kDownloadsFunctionAcceptDanger = 7,
+  kDownloadsFunctionShow = 8,
+  kDownloadsFunctionDrag = 9,
+  kDownloadsFunctionGetFileIcon = 10,
+  kDownloadsFunctionOpen = 11,
+  kDownloadsFunctionRemoveFile = 12,
+  kDownloadsFunctionShowDefaultFolder = 13,
+  kDownloadsFunctionSetShelfEnabled = 14,
+  kDownloadsFunctionDetermineFilename = 15,
+  kDownloadsFunctionSetUiOptions = 16,
   // Insert new values here, not at the beginning.
-  DOWNLOADS_FUNCTION_LAST
+  kDownloadsFunctionLast
 };
 
 void RecordApiFunctions(DownloadsFunctionName function) {
   UMA_HISTOGRAM_ENUMERATION("Download.ApiFunctions", function,
-                            DOWNLOADS_FUNCTION_LAST);
+                            DownloadsFunctionName::kDownloadsFunctionLast);
 }
 
 void CompileDownloadQueryOrderBy(const std::vector<std::string>& order_by_strs,
@@ -1170,7 +1170,7 @@ ExtensionFunction::ResponseAction DownloadsDownloadFunction::Run() {
 
   DownloadManager* manager = browser_context()->GetDownloadManager();
   manager->DownloadUrl(std::move(download_params));
-  RecordApiFunctions(DOWNLOADS_FUNCTION_DOWNLOAD);
+  RecordApiFunctions(DownloadsFunctionName::kDownloadsFunctionDownload);
   return RespondLater();
 }
 
@@ -1248,7 +1248,7 @@ ExtensionFunction::ResponseAction DownloadsSearchFunction::Run() {
                  : profile->GetOriginalProfile());
     json_results.Append(std::move(json_item));
   }
-  RecordApiFunctions(DOWNLOADS_FUNCTION_SEARCH);
+  RecordApiFunctions(DownloadsFunctionName::kDownloadsFunctionSearch);
   return RespondNow(WithArguments(std::move(json_results)));
 }
 
@@ -1271,7 +1271,7 @@ ExtensionFunction::ResponseAction DownloadsPauseFunction::Run() {
   // If the item is already paused, this is a no-op and the operation will
   // silently succeed.
   download_item->Pause();
-  RecordApiFunctions(DOWNLOADS_FUNCTION_PAUSE);
+  RecordApiFunctions(DownloadsFunctionName::kDownloadsFunctionPause);
   return RespondNow(NoArguments());
 }
 
@@ -1294,7 +1294,7 @@ ExtensionFunction::ResponseAction DownloadsResumeFunction::Run() {
   // Note that if the item isn't paused, this will be a no-op, and the extension
   // call will seem successful.
   download_item->Resume(user_gesture());
-  RecordApiFunctions(DOWNLOADS_FUNCTION_RESUME);
+  RecordApiFunctions(DownloadsFunctionName::kDownloadsFunctionResume);
   return RespondNow(NoArguments());
 }
 
@@ -1312,7 +1312,7 @@ ExtensionFunction::ResponseAction DownloadsCancelFunction::Run() {
     download_item->Cancel(true);
   // |download_item| can be NULL if the download ID was invalid or if the
   // download is not currently active.  Either way, it's not a failure.
-  RecordApiFunctions(DOWNLOADS_FUNCTION_CANCEL);
+  RecordApiFunctions(DownloadsFunctionName::kDownloadsFunctionCancel);
   return RespondNow(NoArguments());
 }
 
@@ -1338,7 +1338,7 @@ ExtensionFunction::ResponseAction DownloadsEraseFunction::Run() {
     json_results.Append(static_cast<int>(result->GetId()));
     result->Remove();
   }
-  RecordApiFunctions(DOWNLOADS_FUNCTION_ERASE);
+  RecordApiFunctions(DownloadsFunctionName::kDownloadsFunctionErase);
   return RespondNow(WithArguments(std::move(json_results)));
 }
 
@@ -1359,7 +1359,7 @@ ExtensionFunction::ResponseAction DownloadsRemoveFileFunction::Run() {
       Fault(download_item->GetFileExternallyRemoved(),
             download_extension_errors::kFileAlreadyDeleted, &error))
     return RespondNow(Error(std::move(error)));
-  RecordApiFunctions(DOWNLOADS_FUNCTION_REMOVE_FILE);
+  RecordApiFunctions(DownloadsFunctionName::kDownloadsFunctionRemoveFile);
   download_item->DeleteFile(
       base::BindOnce(&DownloadsRemoveFileFunction::Done, this));
   return RespondLater();
@@ -1429,7 +1429,7 @@ void DownloadsAcceptDangerFunction::PromptOrWait(int download_id, int retries) {
     Respond(Error(download_extension_errors::kInvisibleContext));
     return;
   }
-  RecordApiFunctions(DOWNLOADS_FUNCTION_ACCEPT_DANGER);
+  RecordApiFunctions(DownloadsFunctionName::kDownloadsFunctionAcceptDanger);
   // DownloadDangerPrompt displays a modal dialog using native widgets that the
   // user must either accept or cancel. It cannot be scripted.
   DownloadDangerPrompt* prompt = DownloadDangerPrompt::Create(
@@ -1484,7 +1484,7 @@ ExtensionFunction::ResponseAction DownloadsShowFunction::Run() {
   if (InvalidId(download_item, &error))
     return RespondNow(Error(std::move(error)));
   download_item->ShowDownloadInShell();
-  RecordApiFunctions(DOWNLOADS_FUNCTION_SHOW);
+  RecordApiFunctions(DownloadsFunctionName::kDownloadsFunctionShow);
   return RespondNow(NoArguments());
 }
 
@@ -1503,7 +1503,8 @@ ExtensionFunction::ResponseAction DownloadsShowDefaultFolderFunction::Run() {
       Profile::FromBrowserContext(browser_context()),
       DownloadPrefs::FromDownloadManager(manager)->DownloadPath(),
       platform_util::OPEN_FOLDER, platform_util::OpenOperationCallback());
-  RecordApiFunctions(DOWNLOADS_FUNCTION_SHOW_DEFAULT_FOLDER);
+  RecordApiFunctions(
+      DownloadsFunctionName::kDownloadsFunctionShowDefaultFolder);
   return RespondNow(NoArguments());
 }
 
@@ -1565,7 +1566,7 @@ ExtensionFunction::ResponseAction DownloadsOpenFunction::Run() {
                          params->download_id));
   if (on_prompt_created_cb_)
     std::move(*on_prompt_created_cb_).Run(download_open_prompt);
-  RecordApiFunctions(DOWNLOADS_FUNCTION_OPEN);
+  RecordApiFunctions(DownloadsFunctionName::kDownloadsFunctionOpen);
   return RespondLater();
 }
 
@@ -1601,7 +1602,7 @@ ExtensionFunction::ResponseAction DownloadsSetShelfEnabledFunction::Run() {
     return RespondNow(Error(download_extension_errors::kShelfPermission));
   }
 
-  RecordApiFunctions(DOWNLOADS_FUNCTION_SET_SHELF_ENABLED);
+  RecordApiFunctions(DownloadsFunctionName::kDownloadsFunctionSetShelfEnabled);
   DownloadCoreService* service = nullptr;
   DownloadCoreService* incognito_service = nullptr;
   GetDownloadCoreServices(browser_context(), include_incognito_information(),
@@ -1655,7 +1656,7 @@ ExtensionFunction::ResponseAction DownloadsSetUiOptionsFunction::Run() {
     return RespondNow(Error(download_extension_errors::kUiPermission));
   }
 
-  RecordApiFunctions(DOWNLOADS_FUNCTION_SET_UI_OPTIONS);
+  RecordApiFunctions(DownloadsFunctionName::kDownloadsFunctionSetUiOptions);
   DownloadCoreService* service = nullptr;
   DownloadCoreService* incognito_service = nullptr;
   GetDownloadCoreServices(browser_context(), include_incognito_information(),
@@ -1752,7 +1753,7 @@ void DownloadsGetFileIconFunction::OnIconURLExtracted(const std::string& url) {
     Respond(Error(std::move(error)));
     return;
   }
-  RecordApiFunctions(DOWNLOADS_FUNCTION_GET_FILE_ICON);
+  RecordApiFunctions(DownloadsFunctionName::kDownloadsFunctionGetFileIcon);
   Respond(WithArguments(url));
 }
 
@@ -1896,7 +1897,8 @@ bool ExtensionDownloadsEventRouter::DetermineFilename(
     downloads::FilenameConflictAction conflict_action,
     std::string* error) {
   DCHECK_CURRENTLY_ON(BrowserThread::UI);
-  RecordApiFunctions(DOWNLOADS_FUNCTION_DETERMINE_FILENAME);
+  RecordApiFunctions(
+      DownloadsFunctionName::kDownloadsFunctionDetermineFilename);
   DownloadItem* item =
       GetDownload(browser_context, include_incognito, download_id);
   ExtensionDownloadsEventRouterData* data =
