@@ -501,8 +501,7 @@ bool IsStandardSchemeWithNetworkHost(std::string_view scheme) {
     return true;
 
   url::SchemeType scheme_type;
-  if (!url::GetStandardSchemeType(
-          scheme.data(), url::Component(0, scheme.length()), &scheme_type)) {
+  if (!url::GetStandardSchemeType(scheme, &scheme_type)) {
     return false;
   }
   return scheme_type == url::SCHEME_WITH_HOST_PORT_AND_USER_INFORMATION ||
