@@ -320,8 +320,14 @@ void AddAdditionalData(content::BrowserContext* context,
   dict->Set("pdfUseShowSaveFilePicker",
             base::FeatureList::IsEnabled(
                 chrome_pdf::features::kPdfUseShowSaveFilePicker));
-  dict->Set("pdfSearchifySaveEnabled",
-            chrome_pdf::features::IsPdfSearchifySaveEnabled());
+  dict->Set(
+      "pdfSearchifySaveEnabled",
+      base::FeatureList::IsEnabled(chrome_pdf::features::kPdfSearchifySave));
+
+#if BUILDFLAG(ENABLE_PDF_SAVE_TO_DRIVE)
+  dict->Set("pdfSaveToDrive", base::FeatureList::IsEnabled(
+                                  chrome_pdf::features::kPdfSaveToDrive));
+#endif
 }
 
 bool MaybeDispatchSaveEvent(content::RenderFrameHost* embedder_host) {
