@@ -17,6 +17,7 @@
 
 #include "base/command_line.h"
 #include "base/containers/contains.h"
+#include "base/debug/crash_logging.h"
 #include "base/debug/dump_without_crashing.h"
 #include "base/debug/stack_trace.h"
 #include "base/feature_list.h"
@@ -117,7 +118,6 @@
 
 #if BUILDFLAG(ENABLE_EXTENSIONS)
 #include "extensions/browser/api/management/management_api.h"
-#include "extensions/browser/extension_registrar.h"
 #include "extensions/browser/extension_registry.h"
 #include "extensions/common/extension_set.h"
 #include "extensions/common/manifest.h"
@@ -1192,11 +1192,6 @@ void ProfileManager::InitProfileUserPrefs(Profile* profile) {
     profile->GetPrefs()->SetString(prefs::kSupervisedUserId,
                                    supervised_user_id);
   }
-#if !BUILDFLAG(IS_ANDROID)
-  if (profile->IsNewProfile()) {
-    profile->GetPrefs()->SetBoolean(prefs::kHasSeenWelcomePage, false);
-  }
-#endif  // !BUILDFLAG(IS_ANDROID)
 }
 
 void ProfileManager::RegisterTestingProfile(std::unique_ptr<Profile> profile,
@@ -1464,17 +1459,6 @@ void ProfileManager::DoFinalInitForServices(Profile* profile,
   extensions::ExtensionSystem::Get(profile)->InitForRegularProfile(
       extensions_enabled);
 
-#if BUILDFLAG(ENABLE_EXTENSIONS)
-  // Set the block extensions bit on the ExtensionRegistrar. There likely are no
-  // blockable extensions to block.
-  ProfileAttributesEntry* entry =
-      GetProfileAttributesStorage().GetProfileAttributesWithPath(
-          profile->GetPath());
-  if (entry && entry->IsSigninRequired()) {
-    extensions::ExtensionRegistrar::Get(profile)->BlockAllExtensions();
-  }
-#endif  // BUILDFLAG(ENABLE_EXTENSIONS)
-
 #if BUILDFLAG(IS_CHROMEOS)
   // Ensure that the `ContactCenterInsightsExtensionManager` is instantiated
   // after other systems are set up and only when extensions are enabled for the
@@ -2045,12 +2029,8 @@ void ProfileManager::SetProfileAsLastUsed(Profile* last_active) {
         identity_manager->GetPrimaryAccountInfo(signin::ConsentLevel::kSignin);
     AccountInfo extended_info =
         identity_manager->FindExtendedAccountInfo(account_info);
-    signin::Tribool is_managed =
-        extended_info.hosted_domain.empty()
-            ? signin::Tribool::kUnknown
-            : signin::TriboolFromBool(extended_info.IsManaged());
     active_primary_accounts_metrics_recorder->MarkAccountAsActiveNow(
-        account_info.gaia, is_managed);
+        account_info.gaia, extended_info.IsManaged());
   }
 
   // Don't remember ephemeral profiles as last because they are not going to
