@@ -6,12 +6,14 @@
 
 #include "base/check_op.h"
 #include "base/functional/callback.h"
+#include "base/functional/callback_helpers.h"
 #include "base/logging.h"
 #include "base/metrics/histogram_functions.h"
 #include "base/task/sequenced_task_runner.h"
 #include "base/time/time.h"
 #include "chrome/browser/enterprise/connectors/connectors_service.h"
 #include "chrome/browser/enterprise/data_controls/chrome_rules_service.h"
+#include "chrome/browser/enterprise/data_protection/data_protection_features.h"
 #include "chrome/browser/interstitials/enterprise_util.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/safe_browsing/chrome_enterprise_url_lookup_service_factory.h"
@@ -132,7 +134,6 @@ void OnRealTimeLookupComplete(
     bool is_cached,
     std::unique_ptr<safe_browsing::RTLookupResponse> rt_lookup_response) {
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
-
   if (!is_success) {
     rt_lookup_response.reset();
   }
@@ -169,13 +170,14 @@ void DoLookup(safe_browsing::RealTimeUrlLookupServiceBase* lookup_service,
   DCHECK(!callback.is_null());
   DCHECK(IsEnterpriseLookupEnabled(web_contents->GetBrowserContext()));
   // The referring_app_info parameter to StartLookup is Android-specific.
-  lookup_service->StartLookup(
+  lookup_service->StartMaybeCachedLookup(
       url,
       base::BindOnce(&OnRealTimeLookupComplete, std::move(callback),
                      identifier),
       base::SequencedTaskRunner::GetCurrentDefault(),
       sessions::SessionTabHelper::IdForTab(web_contents),
-      /*referring_app_info=*/std::nullopt);
+      /*referring_app_info=*/std::nullopt, /*use_cache=*/
+      !base::FeatureList::IsEnabled(kEnableSinglePageAppDataProtection));
 }
 
 std::string GetIdentifier(content::BrowserContext* browser_context) {
@@ -201,13 +203,16 @@ bool IsScreenshotAllowedByDataControls(content::BrowserContext* context,
 }  // namespace
 
 // static
-void DataProtectionNavigationObserver::CreateForNavigationIfNeeded(
+std::unique_ptr<DataProtectionNavigationObserver>
+DataProtectionNavigationObserver::CreateForNavigationIfNeeded(
+    DataProtectionNavigationDelegate* delegate,
     Profile* profile,
     content::NavigationHandle* navigation_handle,
     Callback callback) {
-  if (navigation_handle->IsSameDocument() ||
-      !navigation_handle->IsInPrimaryMainFrame()) {
-    return;
+  if (!navigation_handle->IsInPrimaryMainFrame() ||
+      (!base::FeatureList::IsEnabled(kEnableSinglePageAppDataProtection) &&
+       navigation_handle->IsSameDocument())) {
+    return nullptr;
   }
 
 #if BUILDFLAG(SAFE_BROWSING_AVAILABLE)
@@ -218,20 +223,21 @@ void DataProtectionNavigationObserver::CreateForNavigationIfNeeded(
   // protection settings if the enabled state is changed mid session.
   if (SkipUrl(navigation_handle->GetURL())) {
     std::move(callback).Run(UrlSettings::None());
-    return;
+    return nullptr;
   }
 
   // ChromeEnterpriseRealTimeUrlLookupServiceFactory::GetForProfile() return
   // nullptr if enterprise policies are not set.  In this case data protections
   // will be based on data controls alone,
-  enterprise_data_protection::DataProtectionNavigationObserver::
-      CreateForNavigationHandle(
-          *navigation_handle,
-          safe_browsing::ChromeEnterpriseRealTimeUrlLookupServiceFactory::
-              GetForProfile(profile),
-          navigation_handle->GetWebContents(), std::move(callback));
+  return std::make_unique<
+      enterprise_data_protection::DataProtectionNavigationObserver>(
+      *navigation_handle,
+      safe_browsing::ChromeEnterpriseRealTimeUrlLookupServiceFactory::
+          GetForProfile(profile),
+      navigation_handle->GetWebContents(), delegate, std::move(callback));
 #else
   std::move(callback).Run(UrlSettings::None());
+  return nullptr;
 #endif
 }
 
@@ -306,9 +312,12 @@ DataProtectionNavigationObserver::DataProtectionNavigationObserver(
     content::NavigationHandle& navigation_handle,
     safe_browsing::RealTimeUrlLookupServiceBase* lookup_service,
     content::WebContents* web_contents,
+    DataProtectionNavigationDelegate* delegate,
     Callback callback)
     : content::WebContentsObserver(web_contents),
+      navigation_id_(navigation_handle.GetNavigationId()),
       lookup_service_(lookup_service),
+      delegate_(delegate),
       pending_navigation_callback_(std::move(callback)) {
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
   DCHECK(!pending_navigation_callback_.is_null());
@@ -331,6 +340,8 @@ DataProtectionNavigationObserver::DataProtectionNavigationObserver(
              base::BindOnce(&DataProtectionNavigationObserver::OnLookupComplete,
                             weak_factory_.GetWeakPtr()),
              navigation_handle.GetWebContents());
+  } else {
+    is_verdict_received_ = true;
   }
 }
 
@@ -340,8 +351,20 @@ void DataProtectionNavigationObserver::OnLookupComplete(
     std::unique_ptr<safe_browsing::RTLookupResponse> rt_lookup_response) {
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
   DCHECK(!is_from_cache_);
-
-  rt_lookup_response_ = std::move(rt_lookup_response);
+  base::ScopedClosureRunner done(
+      base::BindOnce(&DataProtectionNavigationObserver::MaybeCleanup,
+                     weak_factory_.GetWeakPtr()));
+  is_verdict_received_ = true;
+  if (!web_contents()) {
+    return;
+  }
+  if (is_navigation_finished_) {
+    OnDoLookupComplete(web_contents()->GetWeakPtr(),
+                       std::move(pending_navigation_callback_), identifier_,
+                       std::move(rt_lookup_response));
+  } else {
+    rt_lookup_response_ = std::move(rt_lookup_response);
+  }
 }
 
 bool DataProtectionNavigationObserver::ShouldPerformRealTimeUrlCheck(
@@ -369,8 +392,20 @@ void DataProtectionNavigationObserver::DidRedirectNavigation(
   }
 }
 
+void DataProtectionNavigationObserver::MaybeCleanup() {
+  if (is_navigation_finished_ && is_verdict_received_) {
+    DCHECK(delegate_);
+    delegate_->Cleanup(navigation_id_);
+  }
+}
+
 void DataProtectionNavigationObserver::DidFinishNavigation(
     content::NavigationHandle* navigation_handle) {
+  is_navigation_finished_ = true;
+  base::ScopedClosureRunner done(
+      base::BindOnce(&DataProtectionNavigationObserver::MaybeCleanup,
+                     weak_factory_.GetWeakPtr()));
+
   // Only consider primary main frame commits, which will come eventually.
   // Even though some of these checks where already performed in
   // CreateForNavigationIfNeeded(), they still need to checked again here
@@ -379,8 +414,8 @@ void DataProtectionNavigationObserver::DidFinishNavigation(
   // `pending_navigation_callback_` being null implies `DidFinishNavigation`
   // has already been called, so further lookups/metrics code need to run.
   if (!navigation_handle->IsInPrimaryMainFrame() ||
-      !navigation_handle->HasCommitted() ||
-      !pending_navigation_callback_) {
+      !navigation_handle->HasCommitted() || !pending_navigation_callback_ ||
+      !is_verdict_received_) {
     return;
   }
 
