@@ -122,8 +122,7 @@ void LogPermissionsAiv3HandlerForAiv3(bool exists) {
 }
 
 void LogAiv3RelevanceHasValue(bool has_value) {
-  base::UmaHistogramBoolean("Permissions.AIv3.RelevanceHasValue",
-    has_value);
+  base::UmaHistogramBoolean("Permissions.AIv3.RelevanceHasValue", has_value);
 }
 
 }  // namespace
@@ -271,8 +270,9 @@ void PredictionBasedPermissionUiSelector::OnDeviceAiv3ModelExecutionCallback(
             << static_cast<int>(relevance.value());
     last_permission_request_relevance_ = relevance.value();
     features.permission_relevance = relevance.value();
-    base::UmaHistogramEnumeration("Permissions.AIv3.PermissionRequestRelevance",
-          features.permission_relevance);
+
+    PermissionUmaUtil::RecordPermissionRequestRelevance(
+        request_metadata.request_type, features.permission_relevance, "AIv3");
   } else {
     last_permission_request_relevance_ =
         PermissionRequestRelevance::kUnspecified;
@@ -434,19 +434,18 @@ PredictionBasedPermissionUiSelector::BuildPredictionRequestFeatures(
 
   features.experiment_id =
       PredictionRequestFeatures::ExperimentId::kNoExperimentId;
-  bool use_aiv1 =
-      base::FeatureList::IsEnabled(permissions::features::kPermissionsAIv1);
-  bool use_aiv3 =
-      base::FeatureList::IsEnabled(permissions::features::kPermissionsAIv3) ||
-      base::FeatureList::IsEnabled(
-          permissions::features::kPermissionsAIv3Geolocation);
-  if (use_aiv1 || use_aiv3) {
-    // Init `permission_relevance` here to avoid a crash during
-    // `ConvertToProtoRelevance` execution.
-    features.permission_relevance = PermissionRequestRelevance::kUnspecified;
+
+  // Init `permission_relevance` here to avoid a crash during
+  // `ConvertToProtoRelevance` execution.
+  features.permission_relevance = PermissionRequestRelevance::kUnspecified;
+  // if both Aiv3 and Aiv1 are enabled, we want to chose Aiv3.
+  if (base::FeatureList::IsEnabled(permissions::features::kPermissionsAIv3)) {
     features.experiment_id =
-        use_aiv1 ? PredictionRequestFeatures::ExperimentId::kAiV1ExperimentId
-                 : PredictionRequestFeatures::ExperimentId::kAiV3ExperimentId;
+        PredictionRequestFeatures::ExperimentId::kAiV3ExperimentId;
+  } else if (base::FeatureList::IsEnabled(
+                 permissions::features::kPermissionsAIv1)) {
+    features.experiment_id =
+        PredictionRequestFeatures::ExperimentId::kAiV1ExperimentId;
   }
 
   base::Time cutoff = base::Time::Now() - kPermissionActionCutoffAge;
@@ -491,7 +490,7 @@ void PredictionBasedPermissionUiSelector::OnDeviceAiv1ModelExecutionCallback(
   }
   features.permission_relevance = last_permission_request_relevance_.value();
   PermissionUmaUtil::RecordPermissionRequestRelevance(
-      features.permission_relevance);
+      request_metadata.request_type, features.permission_relevance, "AIv1");
   InquireServerModel(features, std::move(request_metadata),
                      /*record_source=*/!response.has_value());
 }
@@ -629,13 +628,7 @@ PredictionSource PredictionBasedPermissionUiSelector::GetPredictionTypeToUse(
   if (use_server_side) {
     // Aiv3 takes priority over Aiv1 if both are enabled.
 #if BUILDFLAG(BUILD_WITH_TFLITE_LIB)
-    if (request_type == permissions::RequestType::kNotifications &&
-        base::FeatureList::IsEnabled(permissions::features::kPermissionsAIv3)) {
-      return PredictionSource::kOnDeviceAiv3AndServerSideModel;
-    }
-    if (request_type == permissions::RequestType::kGeolocation &&
-        base::FeatureList::IsEnabled(
-            permissions::features::kPermissionsAIv3Geolocation)) {
+    if (base::FeatureList::IsEnabled(permissions::features::kPermissionsAIv3)) {
       return PredictionSource::kOnDeviceAiv3AndServerSideModel;
     }
 #endif  // BUILDFLAG(BUILD_WITH_TFLITE_LIB)
