@@ -166,9 +166,11 @@ RealTimeUrlLookupServiceBase::RealTimeUrlLookupServiceBase(
     base::RepeatingCallback<ChromeUserPopulation()>
         get_user_population_callback,
     ReferrerChainProvider* referrer_chain_provider,
+    std::unique_ptr<SafeBrowsingTokenFetcher> token_fetcher,
     PrefService* pref_service,
     WebUIDelegate* delegate)
-    : url_loader_factory_(url_loader_factory),
+    : token_fetcher_(std::move(token_fetcher)),
+      url_loader_factory_(url_loader_factory),
       cache_manager_(cache_manager),
       pref_service_(pref_service),
       get_user_population_callback_(get_user_population_callback),
@@ -343,25 +345,75 @@ void RealTimeUrlLookupServiceBase::SendSampledRequest(
                    std::move(referring_app_info));
 }
 
+void RealTimeUrlLookupServiceBase::GetAccessToken(
+    const GURL& url,
+    RTLookupResponseCallback response_callback,
+    scoped_refptr<base::SequencedTaskRunner> callback_task_runner,
+    SessionID tab_id,
+    std::optional<internal::ReferringAppInfo> referring_app_info) {
+  token_fetcher_->Start(base::BindOnce(
+      &RealTimeUrlLookupServiceBase::OnGetAccessToken,
+      weak_factory_.GetWeakPtr(), url, std::move(response_callback),
+      std::move(callback_task_runner), base::TimeTicks::Now(), tab_id,
+      std::move(referring_app_info)));
+}
+
+void RealTimeUrlLookupServiceBase::OnGetAccessToken(
+    const GURL& url,
+    RTLookupResponseCallback response_callback,
+    scoped_refptr<base::SequencedTaskRunner> callback_task_runner,
+    base::TimeTicks get_token_start_time,
+    SessionID tab_id,
+    std::optional<internal::ReferringAppInfo> referring_app_info,
+    const std::string& access_token) {
+  if (shutting_down()) {
+    return;
+  }
+
+  RecordTimesWithAndWithoutSuffix(
+      "SafeBrowsing.RT.GetToken.TimeTaken", GetMetricSuffix(),
+      base::TimeTicks::Now() - get_token_start_time);
+  RecordBooleanWithAndWithoutSuffix("SafeBrowsing.RT.HasAccessTokenFromFetcher",
+                                    GetMetricSuffix(), !access_token.empty());
+  MaybeSendRequest(url, access_token, std::move(response_callback),
+                   std::move(callback_task_runner),
+                   /* is_sampled_report */ false, tab_id,
+                   std::move(referring_app_info));
+}
+
 void RealTimeUrlLookupServiceBase::StartLookup(
     const GURL& url,
     RTLookupResponseCallback response_callback,
     scoped_refptr<base::SequencedTaskRunner> callback_task_runner,
     SessionID tab_id,
     std::optional<internal::ReferringAppInfo> referring_app_info) {
+  StartMaybeCachedLookup(url, std::move(response_callback),
+                         callback_task_runner, tab_id,
+                         std::move(referring_app_info), /*use_cache=*/true);
+}
+
+void RealTimeUrlLookupServiceBase::StartMaybeCachedLookup(
+    const GURL& url,
+    RTLookupResponseCallback response_callback,
+    scoped_refptr<base::SequencedTaskRunner> callback_task_runner,
+    SessionID tab_id,
+    std::optional<internal::ReferringAppInfo> referring_app_info,
+    bool use_cache) {
   DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   DCHECK(url.is_valid());
 
   // Check cache.
-  std::unique_ptr<RTLookupResponse> cache_response =
-      GetCachedRealTimeUrlVerdict(url);
-  if (cache_response) {
-    callback_task_runner->PostTask(
-        FROM_HERE, base::BindOnce(std::move(response_callback),
-                                  /* is_rt_lookup_successful */ true,
-                                  /* is_cached_response */ true,
-                                  std::move(cache_response)));
-    return;
+  if (use_cache) {
+    std::unique_ptr<RTLookupResponse> cache_response =
+        GetCachedRealTimeUrlVerdict(url);
+    if (cache_response) {
+      callback_task_runner->PostTask(
+          FROM_HERE, base::BindOnce(std::move(response_callback),
+                                    /* is_rt_lookup_successful */ true,
+                                    /* is_cached_response */ true,
+                                    std::move(cache_response)));
+      return;
+    }
   }
 
   if (IsInBackoffMode()) {
@@ -500,7 +552,7 @@ void RealTimeUrlLookupServiceBase::OnURLLoaderComplete(
 
   if (response_code == net::HTTP_UNAUTHORIZED &&
       access_token_string.has_value()) {
-    OnResponseUnauthorized(access_token_string.value());
+    token_fetcher_->OnInvalidAccessToken(access_token_string.value());
   }
 
   auto response = std::make_unique<RTLookupResponse>();
@@ -712,8 +764,7 @@ void RealTimeUrlLookupServiceBase::OnRequestProtoFilled(
     LogAuthenticatedCookieResets(
         *resource_request,
         SafeBrowsingAuthenticatedEndpoint::kRealtimeUrlLookup);
-    SetAccessTokenAndClearCookieInResourceRequest(resource_request.get(),
-                                                  access_token_string);
+    SetAccessToken(resource_request.get(), access_token_string);
   }
   RecordBooleanWithAndWithoutSuffix("SafeBrowsing.RT.HasTokenInRequest",
                                     GetMetricSuffix(),
@@ -755,9 +806,6 @@ void RealTimeUrlLookupServiceBase::LogLookupResponseForToken(
   webui_delegate_->AddToURTLookupResponses(token.value(), response);
 }
 
-void RealTimeUrlLookupServiceBase::OnResponseUnauthorized(
-    const std::string& invalid_access_token) {}
-
 void RealTimeUrlLookupServiceBase::Shutdown() {
   shutting_down_ = true;
 
@@ -766,6 +814,8 @@ void RealTimeUrlLookupServiceBase::Shutdown() {
   // Clear references to other KeyedServices.
   cache_manager_ = nullptr;
   referrer_chain_provider_ = nullptr;
+
+  token_fetcher_.reset();
 }
 
 }  // namespace safe_browsing
