@@ -252,6 +252,7 @@ const AcceleratorMapping kAcceleratorMap[] = {
 #endif  // !BUILDFLAG(IS_MAC)
 };
 
+#if !BUILDFLAG(IS_MAC) && !BUILDFLAG(IS_CHROMEOS)
 const AcceleratorMapping kTabGroupAcceleratorMap[] = {
     // Tab group commands.
     {ui::VKEY_C, ui::EF_SHIFT_DOWN | ui::EF_ALT_DOWN, IDC_ADD_NEW_TAB_TO_GROUP},
@@ -260,6 +261,7 @@ const AcceleratorMapping kTabGroupAcceleratorMap[] = {
     {ui::VKEY_Z, ui::EF_SHIFT_DOWN | ui::EF_ALT_DOWN, IDC_FOCUS_PREV_TAB_GROUP},
     {ui::VKEY_W, ui::EF_SHIFT_DOWN | ui::EF_ALT_DOWN, IDC_CLOSE_TAB_GROUP},
 };
+#endif  // !BUILDFLAG(IS_MAC) && !BUILDFLAG(IS_CHROMEOS)
 
 const AcceleratorMapping kDevToolsAcceleratorMap[] = {
     {ui::VKEY_F12, ui::EF_NONE, IDC_DEV_TOOLS_TOGGLE},
@@ -324,11 +326,15 @@ std::vector<AcceleratorMapping> GetAcceleratorList() {
                            std::end(kUIDebugAcceleratorMap));
     }
 
+    // Prevent conflicts with global_keyboard_shortcuts_mac.mm and chromeos
+    // accelerators.
+#if !BUILDFLAG(IS_MAC) && !BUILDFLAG(IS_CHROMEOS)
     if (tabs::AreTabGroupShortcutsEnabled()) {
       accelerators->insert(accelerators->end(),
                            std::begin(kTabGroupAcceleratorMap),
                            std::end(kTabGroupAcceleratorMap));
     }
+#endif  // !BUILDFLAG(IS_MAC) && !BUILDFLAG(IS_CHROMEOS)
   }
 
   return *accelerators;
