@@ -15,6 +15,7 @@
 #include "base/strings/utf_string_conversions.h"
 #include "build/build_config.h"
 #include "build/chromeos_buildflags.h"
+#include "chrome/browser/enterprise/connectors/analysis/content_analysis_info.h"
 #include "chrome/browser/enterprise/connectors/common.h"
 #include "chrome/browser/enterprise/connectors/connectors_service.h"
 #include "chrome/browser/policy/chrome_browser_policy_connector.h"
@@ -370,6 +371,7 @@ void SafeBrowsingPrivateEventRouter::OnAnalysisConnectorResult(
     const std::string& trigger,
     const std::string& scan_id,
     const std::string& content_transfer_method,
+    const std::string& source_email,
     safe_browsing::DeepScanAccessPoint access_point,
     const enterprise_connectors::ContentAnalysisResponse::Result& result,
     const int64_t content_size,
@@ -385,8 +387,8 @@ void SafeBrowsingPrivateEventRouter::OnAnalysisConnectorResult(
   } else if (result.tag() == "dlp") {
     OnSensitiveDataEvent(url, tab_url, source, destination, file_name,
                          download_digest_sha256, mime_type, trigger, scan_id,
-                         content_transfer_method, result, content_size,
-                         referrer_chain, event_result);
+                         content_transfer_method, source_email, result,
+                         content_size, referrer_chain, event_result);
   }
 }
 
@@ -465,6 +467,7 @@ void SafeBrowsingPrivateEventRouter::OnSensitiveDataEvent(
     const std::string& trigger,
     const std::string& scan_id,
     const std::string& content_transfer_method,
+    const std::string& source_email,
     const enterprise_connectors::ContentAnalysisResponse::Result& result,
     const int64_t content_size,
     const safe_browsing::ReferrerChain& referrer_chain,
@@ -506,6 +509,15 @@ void SafeBrowsingPrivateEventRouter::OnSensitiveDataEvent(
   if (!content_transfer_method.empty()) {
     event.Set(kKeyContentTransferMethod, content_transfer_method);
   }
+  std::string content_area_account_email =
+      enterprise_connectors::ContentAreaUserProvider::GetUser(
+          Profile::FromBrowserContext(context_), tab_url);
+  if (!content_area_account_email.empty()) {
+    event.Set(kKeyWebAppSignedInAccount, content_area_account_email);
+  }
+  if (!source_email.empty()) {
+    event.Set(kKeySourceWebAppSignedInAccount, source_email);
+  }
 
   AddAnalysisConnectorVerdictToEvent(result, event);
 
@@ -570,6 +582,12 @@ void SafeBrowsingPrivateEventRouter::OnAnalysisConnectorWarningBypassed(
   if (base::FeatureList::IsEnabled(safe_browsing::kEnhancedFieldsForSecOps)) {
     enterprise_connectors::AddReferrerChainToEvent(referrer_chain, event);
   }
+  std::string content_area_account_email =
+      enterprise_connectors::ContentAreaUserProvider::GetUser(
+          Profile::FromBrowserContext(context_), tab_url);
+  if (!content_area_account_email.empty()) {
+    event.Set(kKeyWebAppSignedInAccount, content_area_account_email);
+  }
 
   AddAnalysisConnectorVerdictToEvent(result, event);
 
@@ -811,6 +829,12 @@ void SafeBrowsingPrivateEventRouter::OnDataControlsSensitiveDataEvent(
     event.Set(kKeyContentSize, base::Int64ToValue(content_size));
   }
   event.Set(kKeyTrigger, trigger);
+  std::string content_area_account_email =
+      enterprise_connectors::ContentAreaUserProvider::GetUser(
+          Profile::FromBrowserContext(context_), tab_url);
+  if (!content_area_account_email.empty()) {
+    event.Set(kKeyWebAppSignedInAccount, content_area_account_email);
+  }
   event.Set(kKeyEventResult,
             enterprise_connectors::EventResultToString(event_result));
 
