@@ -54,6 +54,8 @@
 #include "chrome/browser/extensions/forced_extensions/install_stage_tracker.h"
 #include "chrome/browser/extensions/install_verifier.h"
 #include "chrome/browser/extensions/installed_loader.h"
+#include "chrome/browser/extensions/manifest_v2_experiment_manager.h"
+#include "chrome/browser/extensions/mv2_experiment_stage.h"
 #include "chrome/browser/extensions/permissions/permissions_updater.h"
 #include "chrome/browser/extensions/profile_util.h"
 #include "chrome/browser/extensions/unpacked_installer.h"
@@ -122,11 +124,6 @@
 #include "chrome/browser/upgrade_detector/upgrade_detector.h"
 #endif
 
-#if BUILDFLAG(ENABLE_EXTENSIONS)
-#include "chrome/browser/extensions/manifest_v2_experiment_manager.h"
-#include "chrome/browser/extensions/mv2_experiment_stage.h"
-#endif
-
 using content::BrowserContext;
 using content::BrowserThread;
 using extensions::mojom::ManifestLocation;
@@ -313,6 +310,8 @@ void ExtensionService::Shutdown() {
   external_install_manager_ = nullptr;
   updater_ = nullptr;
   component_loader_ = nullptr;
+  host_observation_.RemoveAllObservations();
+  is_shut_down_executed_ = true;
 }
 
 void ExtensionService::Init() {
@@ -362,6 +361,8 @@ void ExtensionService::Init() {
   // rather than running immediately at startup.
   external_provider_manager_->CheckForExternalUpdates();
 
+  LogExtensionsOnChromeUrlsSwitchWarningIfNeeded();
+
   safe_browsing_verdict_handler_.Init();
 
   // Must be called after extensions are loaded.
@@ -390,9 +391,6 @@ void ExtensionService::LoadExtensionsFromCommandLineFlag(
   }
 
   // Check that --load-extension is allowed.
-  // TODO(crbug.com/419530940): Apply restrictions to
-  // --disable-extensions-except switch once the feature is approved and
-  // implemented.
   if (switch_name == switches::kLoadExtension) {
     if (base::FeatureList::IsEnabled(
             extensions_features::kDisableLoadExtensionCommandLineSwitch)) {
@@ -408,6 +406,13 @@ void ExtensionService::LoadExtensionsFromCommandLineFlag(
           << "ExtensionInstallTypeBlocklist::command_line, ignoring.";
       return;
     }
+  } else if (base::FeatureList::IsEnabled(
+                 extensions_features::
+                     kDisableDisableExtensionsExceptCommandLineSwitch)) {
+    DCHECK_EQ(switch_name, switches::kDisableExtensionsExcept);
+    LOG(WARNING) << "--disable-extensions-except is not allowed in Google "
+                    "Chrome, ignoring.";
+    return;
   }
 
   base::CommandLine::StringType path_list =
@@ -519,10 +524,8 @@ void ExtensionService::CheckManagementPolicy() {
     PermissionsUpdater(profile()).ApplyPolicyHostRestrictions(*extension);
   }
 
-#if BUILDFLAG(ENABLE_EXTENSIONS)
   ManifestV2ExperimentManager* mv2_experiment_manager =
       ManifestV2ExperimentManager::Get(profile_);
-#endif
 
   // Loop through the disabled extension list, find extensions to re-enable
   // automatically. These extensions are exclusive from the |to_disable| list
@@ -575,7 +578,6 @@ void ExtensionService::CheckManagementPolicy() {
       to_remove.insert(disable_reason::DISABLE_BLOCKED_BY_POLICY);
     }
 
-#if BUILDFLAG(ENABLE_EXTENSIONS)
     // Note: `mv2_experiment_manager` may be null for certain types of profiles
     // (such as the sign-in profile). We can ignore this check in this case,
     // since users can't install extensions in these profiles.
@@ -588,7 +590,6 @@ void ExtensionService::CheckManagementPolicy() {
         !mv2_experiment_manager->ShouldBlockExtensionEnable(*extension)) {
       to_remove.insert(disable_reason::DISABLE_UNSUPPORTED_MANIFEST_VERSION);
     }
-#endif  // BUILDFLAG(ENABLE_EXTENSIONS)
 
     // If this profile is not supervised, then remove any supervised user
     // related disable reasons.
@@ -929,4 +930,18 @@ void ExtensionService::OnDeveloperModePrefChanged() {
   CheckManagementPolicy();
 }
 
+void ExtensionService::LogExtensionsOnChromeUrlsSwitchWarningIfNeeded() {
+  bool allow_on_chrome_urls = base::CommandLine::ForCurrentProcess()->HasSwitch(
+      switches::kExtensionsOnChromeURLs);
+
+  if (allow_on_chrome_urls &&
+      base::FeatureList::IsEnabled(
+          extensions_features::kDisableExtensionsOnChromeUrlsSwitch)) {
+    LOG(WARNING) << "--extensions-on-chrome-urls is not allowed in Google "
+                    "Chrome, ignoring. "
+                    "Use --extensions-on-extension-urls instead to allow for "
+                    "extensions to run on extension URLs.";
+  }
+}
+
 }  // namespace extensions
