@@ -13,7 +13,7 @@ import 'chrome://resources/cr_elements/cr_button/cr_button.js';
 import 'chrome://resources/cr_elements/cr_icon_button/cr_icon_button.js';
 import 'chrome://resources/cr_elements/cr_link_row/cr_link_row.js';
 import 'chrome://resources/cr_elements/cr_shared_style.css.js';
-import 'chrome://resources/cr_elements/cr_hidden_style.css.js';
+import 'chrome://resources/cr_elements/cr_toast/cr_toast.js';
 import '../controls/settings_toggle_button.js';
 import '../icons.html.js';
 import '../privacy_icons.html.js';
@@ -31,6 +31,7 @@ import {PrefsMixin} from '/shared/settings/prefs/prefs_mixin.js';
 import type {PrivacyPageBrowserProxy} from '/shared/settings/privacy_page/privacy_page_browser_proxy.js';
 import {PrivacyPageBrowserProxyImpl} from '/shared/settings/privacy_page/privacy_page_browser_proxy.js';
 import type {CrLinkRowElement} from 'chrome://resources/cr_elements/cr_link_row/cr_link_row.js';
+import type {CrToastElement} from 'chrome://resources/cr_elements/cr_toast/cr_toast.js';
 import {I18nMixin} from 'chrome://resources/cr_elements/i18n_mixin.js';
 import {WebUiListenerMixin} from 'chrome://resources/cr_elements/web_ui_listener_mixin.js';
 import {assert, assertNotReached} from 'chrome://resources/js/assert.js';
@@ -65,6 +66,7 @@ export interface SettingsPrivacyPageElement {
     clearBrowsingData: CrLinkRowElement,
     permissionsLinkRow: CrLinkRowElement,
     securityLinkRow: CrLinkRowElement,
+    deleteBrowsingDataToast: CrToastElement,
   };
 }
 
@@ -107,13 +109,6 @@ export class SettingsPrivacyPageElement extends SettingsPrivacyPageElementBase {
         },
       },
 
-      enableManagePhones_: {
-        type: Boolean,
-        value() {
-          return loadTimeData.getBoolean('enableSecurityKeysManagePhones');
-        },
-      },
-
       blockAutoplayStatus_: {
         type: Object,
         value() {
@@ -331,6 +326,13 @@ export class SettingsPrivacyPageElement extends SettingsPrivacyPageElementBase {
         value: () => loadTimeData.getBoolean('enableBundledSecuritySettings'),
       },
 
+      // The label of the confirmation toast that is displayed after deletion
+      // from 'Delete Browsing data' is completed.
+      dbdDeletionConfirmationToastLabel_: {
+        type: String,
+        value: '',
+      },
+
       allSitesPageTitle_: String,
     };
   }
@@ -341,7 +343,6 @@ export class SettingsPrivacyPageElement extends SettingsPrivacyPageElementBase {
   declare private showPrivacyGuideDialog_: boolean;
   declare private enableSafeBrowsingSubresourceFilter_: boolean;
   declare private enableBlockAutoplayContentSetting_: boolean;
-  declare private enableManagePhones_: boolean;
   declare private blockAutoplayStatus_: BlockAutoplayStatus;
   declare private enableDeleteBrowsingDataRevamp_: boolean;
   declare private enableFederatedIdentityApiContentSetting_: boolean;
@@ -378,6 +379,7 @@ export class SettingsPrivacyPageElement extends SettingsPrivacyPageElementBase {
   declare private allSitesPageTitle_: string;
   declare private enableIncognitoTrackingProtections_: boolean;
   declare private enableBundledSecuritySettings_: boolean;
+  declare private dbdDeletionConfirmationToastLabel_: string;
 
   override ready() {
     super.ready();
@@ -476,7 +478,8 @@ export class SettingsPrivacyPageElement extends SettingsPrivacyPageElementBase {
 
   private onIncognitoTrackingProtectionsClick_() {
     this.interactedWithPage_();
-    // TODO(crbug.com/408036586): Add user action for Incognito tracking protections row click.
+    this.metricsBrowserProxy_.recordAction(
+        'Settings.TrackingProtections.OpenedFromPrivacyPage');
     Router.getInstance().navigateTo(routes.INCOGNITO_TRACKING_PROTECTIONS);
   }
 
@@ -546,6 +549,12 @@ export class SettingsPrivacyPageElement extends SettingsPrivacyPageElementBase {
     return !this.isPrivacySandboxRestricted_ ||
         this.isPrivacySandboxRestrictedNoticeEnabled_;
   }
+
+  private onBrowsingDataDeleted_(
+      e: CustomEvent<{deletionConfirmationText: string}>) {
+    this.dbdDeletionConfirmationToastLabel_ = e.detail.deletionConfirmationText;
+    this.$.deleteBrowsingDataToast.show();
+  }
 }
 
 declare global {
