@@ -6,6 +6,7 @@
 
 #include <algorithm>
 
+#include "base/barrier_callback.h"
 #include "base/cancelable_callback.h"
 #include "base/containers/span.h"
 #include "base/functional/bind.h"
@@ -359,6 +360,7 @@ void CheckClientDownloadRequestBase::OnRequestBuilt(
   }
 
 #if !BUILDFLAG(IS_ANDROID)
+  // TODO(chlily): Factor this out into delegate's modifications.
   if (is_enhanced_protection_ && token_fetcher_) {
     token_fetcher_->Start(base::BindOnce(
         &CheckClientDownloadRequestBase::OnGotAccessToken, GetWeakPtr()));
@@ -366,6 +368,37 @@ void CheckClientDownloadRequestBase::OnRequestBuilt(
   }
 #endif
 
+  StartModificationsFromDelegate();
+}
+
+void CheckClientDownloadRequestBase::StartModificationsFromDelegate() {
+  std::vector<PendingClientDownloadRequestModification> pending_modifications =
+      service_->delegate()->ProduceClientDownloadRequestModifications(
+          item(), Profile::FromBrowserContext(GetBrowserContext()));
+
+  const auto collect_modifications_repeating =
+      base::BarrierCallback<ClientDownloadRequestModification>(
+          pending_modifications.size(),
+          base::BindOnce(
+              &CheckClientDownloadRequestBase::ApplyModificationsAndSendRequest,
+              GetWeakPtr()));
+
+  // Kick off all the modifications.
+  for (auto& pending_modification : pending_modifications) {
+    // Make a separate copy of the BarrierCallback for each pending
+    // modification. They must each call their own copy of
+    // `collect_modifications_repeating` exactly once.
+    CollectModificationCallback collect_modification =
+        collect_modifications_repeating;
+    std::move(pending_modification).Run(std::move(collect_modification));
+  }
+}
+
+void CheckClientDownloadRequestBase::ApplyModificationsAndSendRequest(
+    std::vector<ClientDownloadRequestModification> modifications) {
+  for (auto& modification : modifications) {
+    std::move(modification).Run(client_download_request_.get());
+  }
   SendRequest();
 }
 
@@ -386,7 +419,8 @@ void CheckClientDownloadRequestBase::StartTimeout() {
 void CheckClientDownloadRequestBase::OnGotAccessToken(
     const std::string& access_token) {
   access_token_ = access_token;
-  SendRequest();
+
+  StartModificationsFromDelegate();
 }
 #endif
 
@@ -402,9 +436,6 @@ void CheckClientDownloadRequestBase::SendRequest() {
       skipped_certificate_allowlist_);
 
   CHECK(service_);
-
-  service_->delegate()->PreSerializeRequest(item(), *client_download_request_);
-
   if (!client_download_request_->SerializeToString(
           &client_download_request_data_)) {
     FinishRequest(DownloadCheckResult::UNKNOWN, REASON_INVALID_REQUEST_PROTO);
@@ -475,8 +506,7 @@ void CheckClientDownloadRequestBase::SendRequest() {
     LogAuthenticatedCookieResets(
         *resource_request,
         SafeBrowsingAuthenticatedEndpoint::kDownloadProtection);
-    SetAccessTokenAndClearCookieInResourceRequest(resource_request.get(),
-                                                  access_token_);
+    SetAccessToken(resource_request.get(), access_token_);
   }
 #endif
 
