@@ -145,7 +145,7 @@ TEST_F(BrowserCommandControllerTest, IsReservedCommandOrKeyIsApp) {
       /*trusted_source=*/true, browser()->window()->GetBounds(), profile(),
       /*user_gesture=*/true);
   params.window = browser()->window();
-  set_browser(Browser::Create(params));
+  set_browser(Browser::DeprecatedCreateOwnedForTesting(params));
 
   ASSERT_TRUE(browser()->is_type_app());
 
@@ -223,7 +223,7 @@ TEST_F(BrowserCommandControllerTest, AppFullScreen) {
       /*trusted_source=*/true, browser()->window()->GetBounds(), profile(),
       /*user_gesture=*/true);
   params.window = browser()->window();
-  set_browser(Browser::Create(params));
+  set_browser(Browser::DeprecatedCreateOwnedForTesting(params));
   ASSERT_TRUE(browser()->is_type_app());
   browser()->command_controller()->FullscreenStateChanged();
   EXPECT_TRUE(chrome::IsCommandEnabled(browser(), IDC_FULLSCREEN));
@@ -669,7 +669,7 @@ TEST_F(CreateShortcutBrowserCommandControllerTest,
   const char kResource[] = "resource.html";
   scoped_refptr<const extensions::Extension> extension =
       CreateAndInstallExtension();
-  AddTab(browser(), extension->GetResourceURL(kResource));
+  AddTab(browser(), extension->ResolveExtensionURL(kResource));
   EXPECT_TRUE(chrome::IsCommandEnabled(browser(), IDC_CREATE_SHORTCUT));
 }
 #endif  // BUILDFLAG(ENABLE_EXTENSIONS)
