@@ -26,6 +26,8 @@
 #include "chrome/browser/enterprise/util/managed_browser_utils.h"
 #include "chrome/browser/feature_engagement/tracker_factory.h"
 #include "chrome/browser/lifetime/application_lifetime.h"
+#include "chrome/browser/profiles/batch_upload/batch_upload_service.h"
+#include "chrome/browser/profiles/batch_upload/batch_upload_service_factory.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/profiles/profile_attributes_entry.h"
 #include "chrome/browser/profiles/profile_avatar_icon_util.h"
@@ -47,12 +49,14 @@
 #include "chrome/browser/ui/browser_list.h"
 #include "chrome/browser/ui/browser_navigator.h"
 #include "chrome/browser/ui/browser_navigator_params.h"
+#include "chrome/browser/ui/browser_window/public/browser_window_features.h"
 #include "chrome/browser/ui/color/chrome_color_id.h"
 #include "chrome/browser/ui/managed_ui.h"
 #include "chrome/browser/ui/passwords/ui_utils.h"
 #include "chrome/browser/ui/profiles/profile_colors_util.h"
 #include "chrome/browser/ui/profiles/profile_picker.h"
 #include "chrome/browser/ui/profiles/profile_view_utils.h"
+#include "chrome/browser/ui/signin/signin_view_controller.h"
 #include "chrome/browser/ui/sync/sync_passphrase_dialog.h"
 #include "chrome/browser/ui/ui_features.h"
 #include "chrome/browser/ui/user_education/browser_user_education_interface.h"
@@ -76,6 +80,8 @@
 #include "components/signin/public/identity_manager/account_info.h"
 #include "components/signin/public/identity_manager/primary_account_mutator.h"
 #include "components/strings/grit/components_strings.h"
+#include "components/sync/base/features.h"
+#include "components/sync/service/sync_service.h"
 #include "components/vector_icons/vector_icons.h"
 #include "net/base/url_util.h"
 #include "ui/base/l10n/l10n_util.h"
@@ -91,6 +97,7 @@
 #include "ui/gfx/paint_vector_icon.h"
 #include "ui/strings/grit/ui_strings.h"
 #include "ui/views/accessibility/view_accessibility.h"
+#include "ui/views/widget/widget.h"
 
 #if BUILDFLAG(IS_MAC) || BUILDFLAG(IS_WIN) || BUILDFLAG(IS_LINUX)
 #include "chrome/browser/enterprise/signin/enterprise_signin_prefs.h"
@@ -208,6 +215,7 @@ ProfileMenuView::ProfileMenuView(
     Browser* browser,
     std::optional<signin_metrics::AccessPoint> explicit_signin_access_point)
     : ProfileMenuViewBase(anchor_button, browser),
+      browser_(raw_ref<Browser>::from_ptr(browser)),
       explicit_signin_access_point_(explicit_signin_access_point) {
   set_close_on_deactivate(close_on_deactivate_for_testing_);
 }
@@ -215,21 +223,20 @@ ProfileMenuView::ProfileMenuView(
 ProfileMenuView::~ProfileMenuView() = default;
 
 void ProfileMenuView::BuildMenu() {
-  Profile* profile = browser()->profile();
-  if (profile->IsGuestSession()) {
+  if (profile().IsGuestSession()) {
     BuildGuestIdentity();
     MaybeBuildCloseBrowsersButton();
     AddBottomMargin();
     return;
   }
 
-  CHECK(!profile->IsOffTheRecord());
+  CHECK(!profile().IsOffTheRecord());
   SetMenuTitleForAccessibility();
   BuildIdentityWithCallToAction();
 
-  const bool is_web_app = web_app::AppBrowserController::IsWebApp(browser());
+  const bool is_web_app = web_app::AppBrowserController::IsWebApp(&browser());
   if (is_web_app) {
-    browser()->window()->NotifyFeaturePromoFeatureUsed(
+    browser().window()->NotifyFeaturePromoFeatureUsed(
         feature_engagement::kIPHPasswordsWebAppProfileSwitchFeature,
         FeaturePromoFeatureUsedAction::kClosePromoIfPresent);
   }
@@ -276,7 +283,7 @@ void ProfileMenuView::OnProfileManagementButtonClicked() {
   if (!perform_menu_actions()) {
     return;
   }
-  chrome::ExecuteCommand(browser(), IDC_SHOW_MANAGEMENT_PAGE);
+  chrome::ExecuteCommand(&browser(), IDC_SHOW_MANAGEMENT_PAGE);
 }
 
 void ProfileMenuView::OnManageGoogleAccountButtonClicked() {
@@ -285,47 +292,21 @@ void ProfileMenuView::OnManageGoogleAccountButtonClicked() {
     return;
   }
 
-  Profile* profile = browser()->profile();
   signin::IdentityManager* identity_manager =
-      IdentityManagerFactory::GetForProfile(profile);
+      IdentityManagerFactory::GetForProfile(&profile());
   DCHECK(identity_manager->HasPrimaryAccount(signin::ConsentLevel::kSignin));
   NavigateToGoogleAccountPage(
-      profile,
+      &profile(),
       identity_manager->GetPrimaryAccountInfo(signin::ConsentLevel::kSignin)
           .email);
 }
 
-void ProfileMenuView::OnPasswordsButtonClicked() {
-  RecordClick(ActionableItem::kPasswordsButton);
-  if (!perform_menu_actions()) {
-    return;
-  }
-  NavigateToManagePasswordsPage(
-      browser(), password_manager::ManagePasswordsReferrer::kProfileChooser);
-}
-
-void ProfileMenuView::OnCreditCardsButtonClicked() {
-  RecordClick(ActionableItem::kCreditCardsButton);
-  if (!perform_menu_actions()) {
-    return;
-  }
-  chrome::ShowSettingsSubPage(browser(), chrome::kPaymentsSubPage);
-}
-
-void ProfileMenuView::OnAddressesButtonClicked() {
-  RecordClick(ActionableItem::kAddressesButton);
-  if (!perform_menu_actions()) {
-    return;
-  }
-  chrome::ShowSettingsSubPage(browser(), chrome::kAddressesSubPage);
-}
-
 void ProfileMenuView::OnGuestProfileButtonClicked() {
   RecordClick(ActionableItem::kGuestProfileButton);
   if (!perform_menu_actions()) {
     return;
   }
-  DCHECK(profiles::IsGuestModeEnabled(*browser()->profile()));
+  DCHECK(profiles::IsGuestModeEnabled(profile()));
   profiles::SwitchToGuestProfile();
 }
 
@@ -334,7 +315,7 @@ void ProfileMenuView::OnExitProfileButtonClicked() {
   if (!perform_menu_actions()) {
     return;
   }
-  profiles::CloseProfileWindows(browser()->profile());
+  profiles::CloseProfileWindows(&profile());
 }
 
 void ProfileMenuView::OnSyncSettingsButtonClicked() {
@@ -342,7 +323,7 @@ void ProfileMenuView::OnSyncSettingsButtonClicked() {
   if (!perform_menu_actions()) {
     return;
   }
-  chrome::ShowSettingsSubPage(browser(), chrome::kSyncSetupSubPage);
+  chrome::ShowSettingsSubPage(&browser(), chrome::kSyncSetupSubPage);
 }
 
 void ProfileMenuView::OnSyncErrorButtonClicked(AvatarSyncErrorType error) {
@@ -354,12 +335,11 @@ void ProfileMenuView::OnSyncErrorButtonClicked(AvatarSyncErrorType error) {
   // The logic below must be consistent with GetSyncInfoForAvatarErrorType().
   switch (error) {
     case AvatarSyncErrorType::kManagedUserUnrecoverableError:
-      chrome::ShowSettingsSubPage(browser(), chrome::kSignOutSubPage);
+      chrome::ShowSettingsSubPage(&browser(), chrome::kSignOutSubPage);
       break;
     case AvatarSyncErrorType::kUnrecoverableError: {
-      Profile* profile = browser()->profile();
       signin::IdentityManager* identity_manager =
-          IdentityManagerFactory::GetForProfile(profile);
+          IdentityManagerFactory::GetForProfile(&profile());
       // This error means that the Sync engine failed to initialize. Shutdown
       // Sync engine by revoking sync consent.
       identity_manager->GetPrimaryAccountMutator()->RevokeSyncConsent(
@@ -367,7 +347,7 @@ void ProfileMenuView::OnSyncErrorButtonClicked(AvatarSyncErrorType error) {
       GetWidget()->CloseWithReason(views::Widget::ClosedReason::kUnspecified);
       // Re-enable sync with the same primary account.
       signin_ui_util::EnableSyncFromSingleAccountPromo(
-          profile,
+          &profile(),
           identity_manager->GetPrimaryAccountInfo(
               signin::ConsentLevel::kSignin),
           signin_metrics::AccessPoint::kAvatarBubbleSignIn);
@@ -376,33 +356,34 @@ void ProfileMenuView::OnSyncErrorButtonClicked(AvatarSyncErrorType error) {
     case AvatarSyncErrorType::kSyncPaused:
       GetWidget()->CloseWithReason(views::Widget::ClosedReason::kUnspecified);
       signin_ui_util::ShowReauthForPrimaryAccountWithAuthError(
-          browser()->profile(),
-          signin_metrics::AccessPoint::kAvatarBubbleSignIn);
+          &profile(), signin_metrics::AccessPoint::kAvatarBubbleSignIn);
       break;
     case AvatarSyncErrorType::kUpgradeClientError:
-      chrome::OpenUpdateChromeDialog(browser());
+      chrome::OpenUpdateChromeDialog(&browser());
       break;
     case AvatarSyncErrorType::kTrustedVaultKeyMissingForEverythingError:
     case AvatarSyncErrorType::kTrustedVaultKeyMissingForPasswordsError:
       OpenTabForSyncKeyRetrieval(
-          browser(), syncer::TrustedVaultUserActionTriggerForUMA::kProfileMenu);
+          &browser(),
+          syncer::TrustedVaultUserActionTriggerForUMA::kProfileMenu);
       break;
     case AvatarSyncErrorType::
         kTrustedVaultRecoverabilityDegradedForEverythingError:
     case AvatarSyncErrorType::
         kTrustedVaultRecoverabilityDegradedForPasswordsError:
       OpenTabForSyncKeyRecoverabilityDegraded(
-          browser(), syncer::TrustedVaultUserActionTriggerForUMA::kProfileMenu);
+          &browser(),
+          syncer::TrustedVaultUserActionTriggerForUMA::kProfileMenu);
       break;
     case AvatarSyncErrorType::kPassphraseError:
       ShowSyncPassphraseDialog(
-          *browser(), base::BindRepeating(
-                          &SyncPassphraseDialogDecryptData,
-                          base::Unretained(SyncServiceFactory::GetForProfile(
-                              browser()->profile()))));
+          browser(),
+          base::BindRepeating(
+              &SyncPassphraseDialogDecryptData,
+              base::Unretained(SyncServiceFactory::GetForProfile(&profile()))));
       break;
     case AvatarSyncErrorType::kSettingsUnconfirmedError:
-      chrome::ShowSettingsSubPage(browser(), chrome::kSyncSetupSubPage);
+      chrome::ShowSettingsSubPage(&browser(), chrome::kSyncSetupSubPage);
       break;
   }
 }
@@ -421,25 +402,28 @@ void ProfileMenuView::OnSigninButtonClicked(
 #if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
   // TODO(crbug.com/404807488): Update the button and the dialog strings.
   if (base::FeatureList::IsEnabled(switches::kEnableHistorySyncOptin)) {
-    browser()->signin_view_controller()->ShowModalHistorySyncOptInDialog();
+    browser()
+        .GetFeatures()
+        .signin_view_controller()
+        ->ShowModalHistorySyncOptInDialog();
     return;
   }
 #endif  // BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
 
   if (button_type == ActionableItem::kSigninReauthButton) {
     // The reauth button does not trigger a sync opt in.
-    signin_ui_util::ShowReauthForAccount(browser()->profile(), account.email,
+    signin_ui_util::ShowReauthForAccount(&profile(), account.email,
                                          access_point);
     return;
   }
-  signin_ui_util::EnableSyncFromSingleAccountPromo(browser()->profile(),
-                                                   account, access_point);
+  signin_ui_util::EnableSyncFromSingleAccountPromo(&profile(), account,
+                                                   access_point);
 }
 
 void ProfileMenuView::OnSignoutButtonClicked() {
   signin::IdentityManager* identity_manager =
-      IdentityManagerFactory::GetForProfile(browser()->profile());
-  DCHECK(ChromeSigninClientFactory::GetForProfile(browser()->profile())
+      IdentityManagerFactory::GetForProfile(&profile());
+  DCHECK(ChromeSigninClientFactory::GetForProfile(&profile())
              ->IsClearPrimaryAccountAllowed(identity_manager->HasPrimaryAccount(
                  signin::ConsentLevel::kSync)))
       << "Clear primary account is not allowed. Signout should not be offered "
@@ -450,7 +434,7 @@ void ProfileMenuView::OnSignoutButtonClicked() {
     return;
   }
   GetWidget()->CloseWithReason(views::Widget::ClosedReason::kUnspecified);
-  browser()->signin_view_controller()->SignoutOrReauthWithPrompt(
+  browser().GetFeatures().signin_view_controller()->SignoutOrReauthWithPrompt(
       signin_metrics::AccessPoint::kProfileMenuSignoutConfirmationPrompt,
       signin_metrics::ProfileSignout::kUserClickedSignoutProfileMenu,
       signin_metrics::SourceForRefreshTokenOperation::
@@ -464,7 +448,7 @@ void ProfileMenuView::OnOtherProfileSelected(
     return;
   }
 
-  if (!web_app::AppBrowserController::IsWebApp(browser())) {
+  if (!web_app::AppBrowserController::IsWebApp(&browser())) {
     GetWidget()->CloseWithReason(views::Widget::ClosedReason::kUnspecified);
     profiles::SwitchToProfile(profile_path, /*always_create=*/false);
   } else {
@@ -474,7 +458,7 @@ void ProfileMenuView::OnOtherProfileSelected(
     // support switching profiles, but also possibly installing the app into a
     // different profile. Regular PWAs can only switch to profiles where the app
     // is already installed.
-    const webapps::AppId& app_id = browser()->app_controller()->app_id();
+    const webapps::AppId& app_id = browser().app_controller()->app_id();
 #if BUILDFLAG(IS_MAC)
     if (app_id != ash::kPasswordManagerAppId) {
       apps::AppShimManager::Get()->LaunchAppInProfile(app_id, profile_path);
@@ -484,7 +468,7 @@ void ProfileMenuView::OnOtherProfileSelected(
     CHECK_EQ(app_id, ash::kPasswordManagerAppId);
 
     app_profile_switcher_.emplace(
-        app_id, *browser()->profile(),
+        app_id, profile(),
         base::BindOnce(
             [](views::Widget* widget) {
               widget->CloseWithReason(
@@ -521,17 +505,7 @@ void ProfileMenuView::OnEditProfileButtonClicked() {
   if (!perform_menu_actions()) {
     return;
   }
-  chrome::ShowSettingsSubPage(browser(), chrome::kManageProfileSubPage);
-}
-
-void ProfileMenuView::OnCookiesClearedOnExitLinkClicked() {
-  RecordClick(ActionableItem::kCookiesClearedOnExitLink);
-  if (!perform_menu_actions()) {
-    return;
-  }
-  chrome::ShowSettingsSubPage(browser(), chrome::kContentSettingsSubPage +
-                                             std::string("/") +
-                                             chrome::kCookieSettingsSubPage);
+  chrome::ShowSettingsSubPage(&browser(), chrome::kManageProfileSubPage);
 }
 
 void ProfileMenuView::OnAutofillSettingsButtonClicked() {
@@ -539,13 +513,22 @@ void ProfileMenuView::OnAutofillSettingsButtonClicked() {
   if (!perform_menu_actions()) {
     return;
   }
-  chrome::ShowSettingsSubPage(browser(), chrome::kAutofillSubPage);
+  chrome::ShowSettingsSubPage(&browser(), chrome::kAutofillSubPage);
+}
+
+void ProfileMenuView::OnBuildBatchUploadButtonClicked() {
+  RecordClick(ActionableItem::kBatchUploadButton);
+  if (!perform_menu_actions()) {
+    return;
+  }
+  BatchUploadServiceFactory::GetForProfile(&profile())
+      ->OpenBatchUpload(&browser(),
+                        BatchUploadService::EntryPoint::kProfileMenu);
 }
 
 void ProfileMenuView::SetMenuTitleForAccessibility() {
-  Profile* profile = browser()->profile();
   const signin::IdentityManager* identity_manager =
-      IdentityManagerFactory::GetForProfile(profile);
+      IdentityManagerFactory::GetForProfile(&profile());
   CoreAccountInfo core_account_info =
       identity_manager->GetPrimaryAccountInfo(signin::ConsentLevel::kSignin);
   AccountInfo account_info =
@@ -556,9 +539,9 @@ void ProfileMenuView::SetMenuTitleForAccessibility() {
     case signin_util::SignedInState::kWebOnlySignedIn: {
       std::string profile_user_display_name, profile_user_email;
 #if BUILDFLAG(IS_MAC) || BUILDFLAG(IS_WIN) || BUILDFLAG(IS_LINUX)
-      profile_user_display_name = profile->GetPrefs()->GetString(
+      profile_user_display_name = profile().GetPrefs()->GetString(
           enterprise_signin::prefs::kProfileUserDisplayName);
-      profile_user_email = profile->GetPrefs()->GetString(
+      profile_user_email = profile().GetPrefs()->GetString(
           enterprise_signin::prefs::kProfileUserEmail);
 #endif
       menu_title_ =
@@ -589,23 +572,11 @@ void ProfileMenuView::BuildGuestIdentity() {
   menu_title_ = l10n_util::GetStringUTF16(IDS_GUEST_PROFILE_NAME);
   menu_subtitle_ = std::u16string();
 
-  if (base::FeatureList::IsEnabled(switches::kEnableImprovedGuestProfileMenu)) {
-    IdentitySectionParams params;
-    params.title = menu_title_;
-    params.profile_image_padding =
-        std::nearbyint(kIdentityInfoImageSize * 0.25f);
-    params.profile_image = profiles::GetGuestAvatar();
-    SetProfileIdentityWithCallToAction(std::move(params));
-  } else {
-    int guest_window_count = BrowserList::GetGuestBrowserCount();
-    if (guest_window_count > 1) {
-      menu_subtitle_ = l10n_util::GetPluralStringFUTF16(
-          IDS_GUEST_WINDOW_COUNT_MESSAGE, guest_window_count);
-    }
-
-    SetProfileIdentityInfo(profiles::GetGuestAvatar(), menu_title_,
-                           menu_subtitle_, &kGuestMenuArtIcon);
-  }
+  IdentitySectionParams params;
+  params.title = menu_title_;
+  params.profile_image_padding = std::nearbyint(kIdentityInfoImageSize * 0.25f);
+  params.profile_image = profiles::GetGuestAvatar();
+  SetProfileIdentityWithCallToAction(std::move(params));
 
   if (GetWidget()) {
     GetWidget()->UpdateAccessibleNameForRootView();
@@ -614,11 +585,10 @@ void ProfileMenuView::BuildGuestIdentity() {
 
 ProfileMenuViewBase::IdentitySectionParams
 ProfileMenuView::GetIdentitySectionParams(const ProfileAttributesEntry& entry) {
-  Profile* profile = browser()->profile();
   const std::optional<AvatarSyncErrorType> error =
-      GetAvatarSyncErrorType(profile);
+      GetAvatarSyncErrorType(&profile());
   const signin::IdentityManager* identity_manager =
-      IdentityManagerFactory::GetForProfile(profile);
+      IdentityManagerFactory::GetForProfile(&profile());
   const bool is_sync_feature_enabled =
       identity_manager->HasPrimaryAccount(signin::ConsentLevel::kSync);
   const CoreAccountInfo primary_account_info =
@@ -640,14 +610,14 @@ ProfileMenuView::GetIdentitySectionParams(const ProfileAttributesEntry& entry) {
           : primary_extended_account_info.account_image);
 
   ui::ImageModel* custom_management_image = nullptr;
-  if (enterprise_util::CanShowEnterpriseBadgingForMenu(profile)) {
-    if (profile->IsChild()) {
+  if (enterprise_util::CanShowEnterpriseBadgingForMenu(&profile())) {
+    if (profile().IsChild()) {
       params.header_string = l10n_util::GetStringUTF16(IDS_MANAGED_BY_PARENT);
     } else {
       params.header_string =
           l10n_util::GetStringUTF16(IDS_PROFILE_MENU_PROFILE_MANAGED_HEADER);
       custom_management_image =
-          policy::ManagementServiceFactory::GetForProfile(profile)
+          policy::ManagementServiceFactory::GetForProfile(&profile())
               ->GetManagementIconForProfile();
     }
 
@@ -658,7 +628,7 @@ ProfileMenuView::GetIdentitySectionParams(const ProfileAttributesEntry& entry) {
       params.header_image = *custom_management_image;
     } else {
       params.header_image = ui::ImageModel::FromVectorIcon(
-          GetManagedUiIcon(profile), ui::kColorIcon);
+          GetManagedUiIcon(&profile()), ui::kColorIcon);
     }
   }
 
@@ -669,7 +639,7 @@ ProfileMenuView::GetIdentitySectionParams(const ProfileAttributesEntry& entry) {
     return params;
   }
 
-  if (web_app::AppBrowserController::IsWebApp(browser())) {
+  if (web_app::AppBrowserController::IsWebApp(&browser())) {
     if (!primary_account_info.email.empty()) {
       params.subtitle = base::UTF8ToUTF16(primary_account_info.email);
     }
@@ -693,7 +663,7 @@ ProfileMenuView::GetIdentitySectionParams(const ProfileAttributesEntry& entry) {
       signin_metrics::AccessPoint::kAvatarBubbleSignIn;
   switch (signin_util::GetSignedInState(identity_manager)) {
     case signin_util::SignedInState::kSignedOut:
-      if (profile->GetPrefs()->GetBoolean(prefs::kSigninAllowed)) {
+      if (profile().GetPrefs()->GetBoolean(prefs::kSigninAllowed)) {
         button_type = ActionableItem::kSigninButton;
         access_point =
             signin_metrics::AccessPoint::kAvatarBubbleSignInWithSyncPromo;
@@ -727,12 +697,12 @@ ProfileMenuView::GetIdentitySectionParams(const ProfileAttributesEntry& entry) {
         ProfileAttributesEntry* profile_attributes =
             g_browser_process->profile_manager()
                 ->GetProfileAttributesStorage()
-                .GetProfileAttributesWithPath(profile->GetPath());
+                .GetProfileAttributesWithPath(profile().GetPath());
         account_image = profile_attributes->GetAvatarIcon(
             /*size_for_placeholder_avatar=*/kIdentityImageSizeForButton,
             /*use_high_res_file=*/true,
             GetPlaceholderAvatarIconParamsVisibleAgainstColor(
-                browser()->window()->GetColorProvider()->GetColor(
+                browser().window()->GetColorProvider()->GetColor(
                     ui::kColorButtonBackgroundProminent)));
       } else {
         account_image = account_info_for_promos.account_image;
@@ -788,11 +758,10 @@ ProfileMenuView::GetIdentitySectionParams(const ProfileAttributesEntry& entry) {
 }
 
 void ProfileMenuView::BuildIdentityWithCallToAction() {
-  Profile* profile = browser()->profile();
   ProfileAttributesEntry* entry =
       g_browser_process->profile_manager()
           ->GetProfileAttributesStorage()
-          .GetProfileAttributesWithPath(profile->GetPath());
+          .GetProfileAttributesWithPath(profile().GetPath());
   if (!entry) {
     // May happen if the profile is being deleted. https://crbug.com/1040079
     return;
@@ -801,25 +770,61 @@ void ProfileMenuView::BuildIdentityWithCallToAction() {
 }
 
 void ProfileMenuView::BuildHistorySyncOptInButton() {
-  CHECK(!browser()->profile()->IsGuestSession());
+  CHECK(!profile().IsGuestSession());
   signin_metrics::AccessPoint access_point =
       explicit_signin_access_point_.value_or(
           signin_metrics::AccessPoint::kAvatarBubbleSignIn);
   signin_metrics::LogSyncOptInOffered(access_point);
-  AddFeatureButton(
+  AddPromoButton(
       l10n_util::GetStringUTF16(IDS_PROFILE_MENU_SYNC_PROMO_ROW_BUTTON_LABEL),
       base::BindRepeating(
           &ProfileMenuView::OnSigninButtonClicked, base::Unretained(this),
-          IdentityManagerFactory::GetForProfile(browser()->profile())
+          IdentityManagerFactory::GetForProfile(&profile())
               ->GetPrimaryAccountInfo(signin::ConsentLevel::kSignin),
           ActionableItem::kHistorySyncOptInButton, access_point),
-      kDevicesChromeRefreshIcon, /*icon_to_image_ratio=*/1.0f,
-      kColorProfileMenuSyncPromoButtonBackground,
-      /*add_vertical_margin=*/true);
+      kDevicesChromeRefreshIcon);
+}
+
+void ProfileMenuView::OnBatchUploadDataReceived(
+    std::map<syncer::DataType, syncer::LocalDataDescription> local_data_map) {
+  size_t local_data_count = std::accumulate(
+      local_data_map.begin(), local_data_map.end(), 0u,
+      [](size_t current_count,
+         std::pair<syncer::DataType, syncer::LocalDataDescription> local_data) {
+        return current_count + local_data.second.local_data_models.size();
+      });
+  if (local_data_count == 0) {
+    return;
+  }
+
+  AddPromoButton(
+      l10n_util::GetPluralStringFUTF16(IDS_PROFILE_MENU_BATCH_UPLOAD_BUTTON,
+                                       local_data_count),
+      base::BindRepeating(&ProfileMenuView::OnBuildBatchUploadButtonClicked,
+                          base::Unretained(this)),
+      vector_icons::kSaveCloudIcon);
+
+  // Adding the button being asynchronous, the menu may be already been shown,
+  // update the view size to accommodate for the addition of the button. In
+  // theory this update should not even be visible to the user.
+  if (views::Widget* widget = GetWidget()) {
+    widget->SetSize(widget->non_client_view()->GetPreferredSize());
+  }
+}
+
+void ProfileMenuView::MaybeBuildBatchUploadButton() {
+  if (!base::FeatureList::IsEnabled(
+          syncer::kReplaceSyncPromosWithSignInPromos)) {
+    return;
+  }
+
+  BatchUploadServiceFactory::GetForProfile(&profile())
+      ->GetLocalDataDescriptionsForAvailableTypes(base::BindOnce(
+          &ProfileMenuView::OnBatchUploadDataReceived, base::Unretained(this)));
 }
 
 void ProfileMenuView::BuildAutofillSettingsButton() {
-  CHECK(!browser()->profile()->IsGuestSession());
+  CHECK(!profile().IsGuestSession());
   AddFeatureButton(
       l10n_util::GetStringUTF16(IDS_PROFILE_MENU_AUTOFILL_SETTINGS_BUTTON),
       base::BindRepeating(&ProfileMenuView::OnAutofillSettingsButtonClicked,
@@ -828,7 +833,7 @@ void ProfileMenuView::BuildAutofillSettingsButton() {
 }
 
 void ProfileMenuView::BuildCustomizeProfileButton() {
-  CHECK(!browser()->profile()->IsGuestSession());
+  CHECK(!profile().IsGuestSession());
   AddFeatureButton(
       l10n_util::GetStringUTF16(IDS_PROFILE_MENU_CUSTOMIZE_PROFILE_BUTTON),
       base::BindRepeating(&ProfileMenuView::OnEditProfileButtonClicked,
@@ -837,11 +842,10 @@ void ProfileMenuView::BuildCustomizeProfileButton() {
 }
 
 void ProfileMenuView::MaybeBuildChromeAccountSettingsButton() {
-  Profile* profile = browser()->profile();
-  CHECK(!profile->IsGuestSession());
+  CHECK(!profile().IsGuestSession());
 
   signin::IdentityManager* identity_manager =
-      IdentityManagerFactory::GetForProfile(profile);
+      IdentityManagerFactory::GetForProfile(&profile());
 
   if (!identity_manager) {
     return;
@@ -852,7 +856,7 @@ void ProfileMenuView::MaybeBuildChromeAccountSettingsButton() {
   const bool should_show_settings_button =
       !identity_manager->GetExtendedAccountInfoForAccountsWithRefreshToken()
            .empty() ||
-      !profile->GetPrefs()->GetBoolean(prefs::kSigninAllowed);
+      !profile().GetPrefs()->GetBoolean(prefs::kSigninAllowed);
   if (!should_show_settings_button) {
     return;
   }
@@ -874,10 +878,9 @@ void ProfileMenuView::MaybeBuildChromeAccountSettingsButton() {
 }
 
 void ProfileMenuView::MaybeBuildManageGoogleAccountButton() {
-  Profile* profile = browser()->profile();
-  CHECK(!profile->IsGuestSession());
+  CHECK(!profile().IsGuestSession());
   signin::IdentityManager* identity_manager =
-      IdentityManagerFactory::GetForProfile(profile);
+      IdentityManagerFactory::GetForProfile(&profile());
 
   if (!identity_manager) {
     return;
@@ -918,17 +921,13 @@ void ProfileMenuView::MaybeBuildManageGoogleAccountButton() {
 }
 
 void ProfileMenuView::MaybeBuildCloseBrowsersButton() {
-  Profile* profile = browser()->profile();
-  const int window_count = CountBrowsersFor(profile);
+  const int window_count = CountBrowsersFor(&profile());
   base::RepeatingClosure callback = base::BindRepeating(
       &ProfileMenuView::OnExitProfileButtonClicked, base::Unretained(this));
   int button_title_id = IDS_PROFILE_MENU_CLOSE_PROFILE_X_WINDOWS_BUTTON;
 
-  if (profile->IsGuestSession()) {
-    button_title_id =
-        base::FeatureList::IsEnabled(switches::kEnableImprovedGuestProfileMenu)
-            ? IDS_GUEST_PROFILE_MENU_CLOSE_X_WINDOWS_BUTTON
-            : IDS_GUEST_PROFILE_MENU_CLOSE_BUTTON;
+  if (profile().IsGuestSession()) {
+    button_title_id = IDS_GUEST_PROFILE_MENU_CLOSE_X_WINDOWS_BUTTON;
   } else {
     // Show the button only if the current profile has multiple windows open.
     if (window_count <= 1) {
@@ -938,10 +937,11 @@ void ProfileMenuView::MaybeBuildCloseBrowsersButton() {
     // And there are multiple profiles open.
     std::vector<Profile*> loaded_profiles =
         g_browser_process->profile_manager()->GetLoadedProfiles();
+    Profile* profile_ptr = &profile();
     bool other_profile_open =
         std::any_of(loaded_profiles.begin(), loaded_profiles.end(),
-                    [&profile](Profile* loaded_profile) {
-                      if (loaded_profile == profile) {
+                    [profile_ptr](Profile* loaded_profile) {
+                      if (loaded_profile == profile_ptr) {
                         return false;
                       }
                       return CountBrowsersFor(loaded_profile) > 0;
@@ -957,19 +957,18 @@ void ProfileMenuView::MaybeBuildCloseBrowsersButton() {
 }
 
 void ProfileMenuView::MaybeBuildSignoutButton() {
-  Profile* profile = browser()->profile();
-  CHECK(!profile->IsGuestSession());
+  CHECK(!profile().IsGuestSession());
   signin::IdentityManager* identity_manager =
-      IdentityManagerFactory::GetForProfile(profile);
+      IdentityManagerFactory::GetForProfile(&profile());
   if (!identity_manager) {
     return;
   }
 
   const bool hide_signout_button_for_managed_profiles =
-      enterprise_util::UserAcceptedAccountManagement(profile);
+      enterprise_util::UserAcceptedAccountManagement(&profile());
 
   const bool add_sign_out_button =
-      HasUnconstentedProfile(profile) &&
+      HasUnconstentedProfile(&profile()) &&
       !identity_manager->HasPrimaryAccount(signin::ConsentLevel::kSync) &&
       !hide_signout_button_for_managed_profiles;
   if (!add_sign_out_button) {
@@ -993,12 +992,14 @@ void ProfileMenuView::MaybeBuildSignoutButton() {
 }
 
 void ProfileMenuView::BuildFeatureButtons() {
-  CHECK(!browser()->profile()->IsGuestSession());
+  CHECK(!profile().IsGuestSession());
   if (signin_util::GetSignedInState(IdentityManagerFactory::GetForProfile(
-          browser()->profile())) == signin_util::SignedInState::kSignedIn &&
+          &profile())) == signin_util::SignedInState::kSignedIn &&
       IsNewSyncPromoVariantEnabled()) {
     BuildHistorySyncOptInButton();
   }
+  // May add the button asynchronously, order is not be guaranteed.
+  MaybeBuildBatchUploadButton();
   BuildAutofillSettingsButton();
   MaybeBuildManageGoogleAccountButton();
   BuildCustomizeProfileButton();
@@ -1009,16 +1010,16 @@ void ProfileMenuView::BuildFeatureButtons() {
 
 void ProfileMenuView::GetProfilesForOtherProfilesSection(
     std::vector<ProfileAttributesEntry*>& available_profiles) const {
-  CHECK(!browser()->profile()->IsGuestSession());
+  CHECK(!profile().IsGuestSession());
 #if BUILDFLAG(IS_MAC)
   const bool is_regular_web_app =
-      web_app::AppBrowserController::IsWebApp(browser()) &&
-      (browser()->app_controller()->app_id() != ash::kPasswordManagerAppId);
+      web_app::AppBrowserController::IsWebApp(&browser()) &&
+      (browser().app_controller()->app_id() != ash::kPasswordManagerAppId);
   std::set<base::FilePath> available_profile_paths;
   if (is_regular_web_app) {
     available_profile_paths =
         AppShimRegistry::Get()->GetInstalledProfilesForApp(
-            browser()->app_controller()->app_id());
+            browser().app_controller()->app_id());
   }
 #endif
 
@@ -1027,7 +1028,7 @@ void ProfileMenuView::GetProfilesForOtherProfilesSection(
                              .GetAllProfilesAttributesSortedByNameWithCheck();
   for (ProfileAttributesEntry* profile_entry : profile_entries) {
     // The current profile is excluded.
-    if (profile_entry->GetPath() == browser()->profile()->GetPath()) {
+    if (profile_entry->GetPath() == profile().GetPath()) {
       continue;
     }
     if (profile_entry->IsOmitted()) {
@@ -1053,7 +1054,7 @@ void ProfileMenuView::BuildOtherProfilesSection(
             kOtherProfileImageSize,
             /*use_high_res_file=*/true,
             GetPlaceholderAvatarIconParamsVisibleAgainstColor(
-                browser()->window()->GetColorProvider()->GetColor(
+                browser().window()->GetColorProvider()->GetColor(
                     ui::kColorMenuBackground)))),
         profile_entry->GetName(),
         /*is_guest=*/false,
@@ -1063,7 +1064,7 @@ void ProfileMenuView::BuildOtherProfilesSection(
 }
 
 void ProfileMenuView::BuildProfileManagementFeatureButtons() {
-  CHECK(!browser()->profile()->IsGuestSession());
+  CHECK(!profile().IsGuestSession());
 
   AddProfileManagementFeaturesSeparator();
 
@@ -1075,8 +1076,8 @@ void ProfileMenuView::BuildProfileManagementFeatureButtons() {
                             base::Unretained(this)));
   }
 
-  if (profiles::IsGuestModeEnabled(*browser()->profile()) &&
-      !web_app::AppBrowserController::IsWebApp(browser())) {
+  if (profiles::IsGuestModeEnabled(profile()) &&
+      !web_app::AppBrowserController::IsWebApp(&browser())) {
     AddProfileManagementFeatureButton(
         kAccountBoxIcon,
         l10n_util::GetStringUTF16(IDS_PROFILE_MENU_OPEN_GUEST_PROFILE),
