@@ -170,17 +170,6 @@ std::vector<const AutofillProfile*> AddressDataManager::GetProfiles(
     ProfileOrder order) const {
   std::vector<const AutofillProfile*> profiles =
       base::ToVector(profiles_, [](const AutofillProfile& p) { return &p; });
-  // Filter incomplete H/W addresses.
-  std::erase_if(profiles, [&](const AutofillProfile* p) {
-    switch (p->record_type()) {
-      case AutofillProfile::RecordType::kLocalOrSyncable:
-      case AutofillProfile::RecordType::kAccount:
-        return false;
-      case AutofillProfile::RecordType::kAccountHome:
-      case AutofillProfile::RecordType::kAccountWork:
-        return !IsMinimumAddress(*p);
-    }
-  });
   OrderProfiles(profiles, order);
   return profiles;
 }
@@ -203,16 +192,8 @@ std::vector<const AutofillProfile*> AddressDataManager::GetProfilesToSuggest()
   std::vector<const AutofillProfile*> profiles =
       GetProfiles(ProfileOrder::kHighestFrecencyDesc);
   // H/W addresses are prioritized for suggestion purposes.
-  std::ranges::stable_partition(profiles, [](const AutofillProfile* p) {
-    switch (p->record_type()) {
-      case AutofillProfile::RecordType::kLocalOrSyncable:
-      case AutofillProfile::RecordType::kAccount:
-        return false;
-      case AutofillProfile::RecordType::kAccountHome:
-      case AutofillProfile::RecordType::kAccountWork:
-        return true;
-    }
-  });
+  std::ranges::stable_partition(profiles,
+                                &AutofillProfile::IsHomeAndWorkProfile);
   if (profiles.size() >= 2 &&
       profiles[0]->record_type() == AutofillProfile::RecordType::kAccountWork &&
       profiles[1]->record_type() == AutofillProfile::RecordType::kAccountHome) {
