@@ -36,6 +36,7 @@
 #include "components/sync/protocol/nigori_specifics.pb.h"
 #include "components/sync/service/glue/sync_transport_data_prefs.h"
 #include "components/sync/service/sync_feature_status_for_migrations_recorder.h"
+#include "extensions/buildflags/buildflags.h"
 #include "google_apis/gaia/gaia_id.h"
 
 namespace syncer {
@@ -228,7 +229,14 @@ bool SyncPrefs::IsInitialSyncFeatureSetupComplete() const {
 }
 
 bool SyncPrefs::IsExplicitBrowserSignin() const {
+#if BUILDFLAG(IS_ANDROID) || BUILDFLAG(IS_IOS) || BUILDFLAG(IS_CHROMEOS)
+  // On mobile and ChromeOS all sign-ins are considered explicit.
+  return true;
+#else
+  // On desktop `prefs::kExplicitBrowserSignin` determines whether the sign-in
+  // is explicit or implicit.
   return pref_service_->GetBoolean(::prefs::kExplicitBrowserSignin);
+#endif
 }
 
 #if !BUILDFLAG(IS_CHROMEOS)
@@ -288,54 +296,8 @@ UserSelectableTypeSet SyncPrefs::GetSelectedTypesForAccount(
           gaia_id_hash, pref_name);
       if (pref_value && pref_value->is_bool()) {
         type_enabled = pref_value->GetBool();
-      } else if (type == UserSelectableType::kHistory ||
-                 type == UserSelectableType::kTabs ||
-                 type == UserSelectableType::kSavedTabGroups) {
-        // History, Tabs, Saved Tab Groups and and Shared Tab Group Data are
-        // disabled by default.
-        type_enabled = false;
-      } else if (type == UserSelectableType::kPasswords ||
-                 type == UserSelectableType::kAutofill) {
-#if BUILDFLAG(IS_ANDROID) || BUILDFLAG(IS_IOS)
-        type_enabled = true;
-#else
-        // kPasswords and kAutofill are only on by default if there was an
-        // explicit sign in recorded.
-        // Otherwise:
-        // - kPasswords requires a dedicated opt-in.
-        // - kAutofill cannot be enabled.
-        // Note: If this changes, also update the migration logic in
-        // MigrateGlobalDataTypePrefsToAccount().
-        type_enabled =
-            pref_service_->GetBoolean(::prefs::kExplicitBrowserSignin);
-#endif
-      } else if (type == UserSelectableType::kBookmarks ||
-                 type == UserSelectableType::kReadingList) {
-#if BUILDFLAG(IS_ANDROID) || BUILDFLAG(IS_IOS)
-        type_enabled =
-            base::FeatureList::IsEnabled(kReplaceSyncPromosWithSignInPromos);
-#else
-        // Bookmarks and Reading List require a specific explicit sign in.
-        type_enabled = SigninPrefs(*pref_service_)
-                           .GetBookmarksExplicitBrowserSignin(gaia_id) ||
-                       base::FeatureList::IsEnabled(
-                           kEnableBookmarksSelectedTypeOnSigninForTesting);
-#endif
-      } else if (type == UserSelectableType::kExtensions) {
-        // Extensions require a specific explicit sign in.
-        type_enabled = SigninPrefs(*pref_service_)
-                           .GetExtensionsExplicitBrowserSignin(gaia_id);
-      } else if (type == UserSelectableType::kPreferences ||
-                 type == UserSelectableType::kThemes) {
-#if BUILDFLAG(IS_ANDROID) || BUILDFLAG(IS_IOS)
-        type_enabled = true;
-#else
-        type_enabled = pref_service_->GetBoolean(
-            ::prefs::kPrefsThemesSearchEnginesAccountStorageEnabled);
-#endif
       } else {
-        // All other types are always enabled by default.
-        type_enabled = true;
+        type_enabled = IsTypeSelectedByDefaultInTransportMode(type, gaia_id);
       }
     }
     if (type_enabled) {
@@ -776,12 +738,7 @@ bool SyncPrefs::IsTypeSupportedInTransportMode(UserSelectableType type) {
       // transport mode everywhere.
       return true;
     case UserSelectableType::kHistory:
-#if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
-      return base::FeatureList::IsEnabled(kReplaceSyncPromosWithSignInPromos) ||
-             base::FeatureList::IsEnabled(switches::kEnableHistorySyncOptin);
-#else
       return base::FeatureList::IsEnabled(kReplaceSyncPromosWithSignInPromos);
-#endif
     case UserSelectableType::kTabs:
       return base::FeatureList::IsEnabled(kReplaceSyncPromosWithSignInPromos);
     case UserSelectableType::kProductComparison:
@@ -789,8 +746,12 @@ bool SyncPrefs::IsTypeSupportedInTransportMode(UserSelectableType type) {
     case UserSelectableType::kSavedTabGroups:
       return base::FeatureList::IsEnabled(kReplaceSyncPromosWithSignInPromos);
     case UserSelectableType::kExtensions:
+#if BUILDFLAG(ENABLE_DESKTOP_ANDROID_EXTENSIONS)
+      return true;
+#else
       return base::FeatureList::IsEnabled(
           switches::kEnableExtensionsExplicitBrowserSignin);
+#endif
     case UserSelectableType::kThemes:
 #if BUILDFLAG(IS_ANDROID) || BUILDFLAG(IS_IOS)
       return false;
@@ -801,8 +762,11 @@ bool SyncPrefs::IsTypeSupportedInTransportMode(UserSelectableType type) {
     case UserSelectableType::kApps:
     case UserSelectableType::kCookies:
       // These types are not supported in transport mode yet.
+      // TODO(crbug.com/420912307): `kApps` should be allowed in
+      // `kReplaceSyncPromosWithSignInPromos` is enabled.
       return false;
   }
+  NOTREACHED();
 }
 
 void SyncPrefs::OnSyncManagedPrefChanged() {
@@ -1153,4 +1117,53 @@ void SyncPrefs::SetPasswordSyncAllowed(bool allowed) {
   }
 }
 
+bool SyncPrefs::IsTypeSelectedByDefaultInTransportMode(
+    UserSelectableType type,
+    const GaiaId& gaia_id) const {
+  // If sign-in is implicit (legacy desktop Dice state), only payments is on by
+  // default.
+  if (!IsExplicitBrowserSignin()) {
+    return type == UserSelectableType::kPayments;
+  }
+
+  switch (type) {
+    case UserSelectableType::kPayments:
+    case UserSelectableType::kPasswords:
+    case UserSelectableType::kAutofill:
+      return true;
+    case UserSelectableType::kHistory:
+    case UserSelectableType::kTabs:
+    case UserSelectableType::kSavedTabGroups:
+      // History and tabs require a separate opt in.
+      return false;
+    case UserSelectableType::kBookmarks:
+    case UserSelectableType::kReadingList:
+      // Before kReplaceSyncPromosWithSignInPromos, Bookmarks and Reading List
+      // require a specific explicit sign in (relevant for desktop only).
+      return base::FeatureList::IsEnabled(kReplaceSyncPromosWithSignInPromos) ||
+             SigninPrefs(*pref_service_)
+                 .GetBookmarksExplicitBrowserSignin(gaia_id) ||
+             base::FeatureList::IsEnabled(
+                 kEnableBookmarksSelectedTypeOnSigninForTesting);
+    case UserSelectableType::kPreferences:
+    case UserSelectableType::kThemes:
+      return base::FeatureList::IsEnabled(kReplaceSyncPromosWithSignInPromos) ||
+             pref_service_->GetBoolean(
+                 ::prefs::kPrefsThemesSearchEnginesAccountStorageEnabled);
+    case UserSelectableType::kExtensions:
+      // Before kReplaceSyncPromosWithSignInPromos, Extensions require a
+      // specific explicit sign in.
+      return base::FeatureList::IsEnabled(kReplaceSyncPromosWithSignInPromos) ||
+             SigninPrefs(*pref_service_)
+                 .GetExtensionsExplicitBrowserSignin(gaia_id);
+    case UserSelectableType::kApps:
+    case UserSelectableType::kProductComparison:
+    case UserSelectableType::kCookies:
+      // All other types are always enabled by default with
+      // kReplaceSyncPromosWithSignInPromos.
+      return base::FeatureList::IsEnabled(kReplaceSyncPromosWithSignInPromos);
+  }
+  NOTREACHED();
+}
+
 }  // namespace syncer
