@@ -122,6 +122,7 @@
 #include "third_party/blink/public/common/origin_trials/origin_trials_settings_provider.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/color/color_provider_manager.h"
+#include "ui/gl/gl_switches.h"
 
 // Per-platform #include blocks, in alphabetical order.
 
@@ -143,6 +144,7 @@
 #include "chrome/browser/usb/web_usb_detector.h"
 #include "chrome/browser/win/browser_util.h"
 #include "components/soda/soda_installer.h"
+#include "components/soda/soda_util.h"
 #endif
 
 #if !BUILDFLAG(IS_ANDROID) || BUILDFLAG(ENABLE_RLZ)
@@ -1005,20 +1007,23 @@ int ChromeBrowserMainParts::PreCreateThreadsImpl() {
         !base::CommandLine::ForCurrentProcess()->HasSwitch(switches::kAppId)) {
       browser_creator_->AddFirstRunTabs(master_prefs_->new_tabs);
     }
-
-#if BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_MAC)
-    // Create directory for user-level Native Messaging manifest files. This
-    // makes it less likely that the directory will be created by third-party
-    // software with incorrect owner or permission. See crbug.com/725513 .
-    base::FilePath user_native_messaging_dir;
-    CHECK(base::PathService::Get(chrome::DIR_USER_NATIVE_MESSAGING,
-                                 &user_native_messaging_dir));
-    if (!base::PathExists(user_native_messaging_dir))
-      base::CreateDirectory(user_native_messaging_dir);
-#endif
   }
 #endif  // !BUILDFLAG(IS_ANDROID) && !BUILDFLAG(IS_CHROMEOS)
 
+#if BUILDFLAG(ENABLE_EXTENSIONS_CORE) &&                                   \
+    (BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_MAC) || \
+     BUILDFLAG(IS_ANDROID))
+  // Create directory for user-level Native Messaging manifest files. This
+  // makes it less likely that the directory will be created by third-party
+  // software with incorrect owner or permission. See crbug.com/725513 .
+  base::FilePath user_native_messaging_dir;
+  CHECK(base::PathService::Get(chrome::DIR_USER_NATIVE_MESSAGING,
+                               &user_native_messaging_dir));
+  if (!base::PathExists(user_native_messaging_dir)) {
+    base::CreateDirectory(user_native_messaging_dir);
+  }
+#endif
+
 #if BUILDFLAG(IS_MAC)
 #if defined(ARCH_CPU_X86_64)
   // The use of Rosetta to run the x64 version of Chromium on Arm is neither
@@ -1077,6 +1082,10 @@ int ChromeBrowserMainParts::PreCreateThreadsImpl() {
     command_line->AppendSwitch(net::kRemoveWhitespaceForDataURLs);
   }
 
+  if (local_state->GetBoolean(prefs::kEnableUnsafeSwiftShader)) {
+    command_line->AppendSwitch(switches::kEnableUnsafeSwiftShader);
+  }
+
 #if BUILDFLAG(IS_ANDROID)
   // The admin should also be able to use these policies to force Site Isolation
   // off (on Android; using enterprise policies to disable Site Isolation is not
@@ -1191,10 +1200,12 @@ void ChromeBrowserMainParts::PreProfileInit() {
 #endif
 
 #if BUILDFLAG(IS_MAC)
-  if (base::FeatureList::IsEnabled(features::kViewsJSAppModalDialog))
+  if (base::FeatureList::IsEnabled(features::kViewsJSAppModalDialog) ||
+      headless::IsHeadlessMode()) {
     InstallChromeJavaScriptAppModalDialogViewFactory();
-  else
+  } else {
     InstallChromeJavaScriptAppModalDialogViewCocoaFactory();
+  }
 #else
   InstallChromeJavaScriptAppModalDialogViewFactory();
 #endif
@@ -1260,6 +1271,9 @@ void ChromeBrowserMainParts::PostProfileInit(Profile* profile,
 #if !BUILDFLAG(IS_ANDROID)
   if (ShouldInstallSodaDuringPostProfileInit(
           *base::CommandLine::ForCurrentProcess(), profile)) {
+    base::UmaHistogramBoolean(
+        "Accessibility.WebSpeech.IsOnDeviceSpeechRecognitionSupported",
+        speech::IsOnDeviceSpeechRecognitionSupported());
     speech::SodaInstaller::GetInstance()->Init(profile->GetPrefs(),
                                                browser_process_->local_state());
   }
