@@ -61,18 +61,15 @@ BASE_FEATURE(kOfferPinToTaskbarWhenSettingToDefault,
 BASE_FEATURE(kOfferPinToTaskbarInFirstRunExperience,
              "OfferPinToTaskbarInFirstRunExperience",
              base::FEATURE_DISABLED_BY_DEFAULT);
+BASE_FEATURE(kOfferPinToTaskbarInfoBar,
+             "OfferPinToTaskbarInfoBar",
+             base::FEATURE_DISABLED_BY_DEFAULT);
 #endif
 
 #if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC)
 // Shows an infobar on PDFs offering to become the default PDF viewer if Chrome
 // isn't the default already.
 BASE_FEATURE(kPdfInfoBar, "PdfInfoBar", base::FEATURE_DISABLED_BY_DEFAULT);
-constexpr base::FeatureParam<PdfInfoBarTrigger>::Option
-    kPdfInfoBarTriggerOptions[] = {{PdfInfoBarTrigger::kPdfLoad, "pdf-load"},
-                                   {PdfInfoBarTrigger::kStartup, "startup"}};
-constexpr base::FeatureParam<PdfInfoBarTrigger> kPdfInfoBarTrigger = {
-    &kPdfInfoBar, "trigger", PdfInfoBarTrigger::kPdfLoad,
-    &kPdfInfoBarTriggerOptions};
 #endif  // BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC)
 
 // Preloads a WebContents with a Top Chrome WebUI on BrowserView initialization,
@@ -81,35 +78,6 @@ BASE_FEATURE(kPreloadTopChromeWebUI,
              "PreloadTopChromeWebUI",
              base::FEATURE_ENABLED_BY_DEFAULT);
 
-const char kPreloadTopChromeWebUIModeName[] = "preload-mode";
-const char kPreloadTopChromeWebUIModePreloadOnWarmupName[] =
-    "preload-on-warmup";
-const char kPreloadTopChromeWebUIModePreloadOnMakeContentsName[] =
-    "preload-on-make-contents";
-constexpr base::FeatureParam<PreloadTopChromeWebUIMode>::Option
-    kPreloadTopChromeWebUIModeOptions[] = {
-        {PreloadTopChromeWebUIMode::kPreloadOnWarmup,
-         kPreloadTopChromeWebUIModePreloadOnWarmupName},
-        {PreloadTopChromeWebUIMode::kPreloadOnMakeContents,
-         kPreloadTopChromeWebUIModePreloadOnMakeContentsName},
-};
-const base::FeatureParam<PreloadTopChromeWebUIMode> kPreloadTopChromeWebUIMode{
-    &kPreloadTopChromeWebUI, kPreloadTopChromeWebUIModeName,
-    PreloadTopChromeWebUIMode::kPreloadOnWarmup,
-    &kPreloadTopChromeWebUIModeOptions};
-
-const char kPreloadTopChromeWebUISmartPreloadName[] = "smart-preload";
-const base::FeatureParam<bool> kPreloadTopChromeWebUISmartPreload{
-    &kPreloadTopChromeWebUI, kPreloadTopChromeWebUISmartPreloadName, true};
-
-const char kPreloadTopChromeWebUIDelayPreloadName[] = "delay-preload";
-const base::FeatureParam<bool> kPreloadTopChromeWebUIDelayPreload{
-    &kPreloadTopChromeWebUI, kPreloadTopChromeWebUIDelayPreloadName, true};
-
-const char kPreloadTopChromeWebUIExcludeOriginsName[] = "exclude-origins";
-const base::FeatureParam<std::string> kPreloadTopChromeWebUIExcludeOrigins{
-    &kPreloadTopChromeWebUI, kPreloadTopChromeWebUIExcludeOriginsName, ""};
-
 // An experiment to reduce the number of navigations when preloading WebUIs.
 BASE_FEATURE(kPreloadTopChromeWebUILessNavigations,
              "PreloadTopChromeWebUILessNavigations",
@@ -138,6 +106,35 @@ BASE_FEATURE(KScrimForTabModal,
 
 BASE_FEATURE(kSideBySide, "SideBySide", base::FEATURE_DISABLED_BY_DEFAULT);
 
+// The delay before showing the drop target for the side-by-side drag-and-drop
+// entrypoint.
+BASE_FEATURE_PARAM(base::TimeDelta,
+                   kSideBySideShowDropTargetDelay,
+                   &kSideBySide,
+                   "drop_target_show_delay",
+                   base::Seconds(1));
+
+// The padding inside the drop target that determines the overall width.
+BASE_FEATURE_PARAM(int,
+                   kSideBySideDropTargetInnerPadding,
+                   &kSideBySide,
+                   "drop_target_inner_padding",
+                   37);
+
+constexpr base::FeatureParam<MiniToolbarActiveConfiguration>::Option
+    kMiniToolbarActiveConfigurationOptions[] = {
+        {MiniToolbarActiveConfiguration::Hide, "hide"},
+        {MiniToolbarActiveConfiguration::ShowMenuOnly, "showmenuonly"},
+        {MiniToolbarActiveConfiguration::ShowAll, "showall"}};
+
+// The active configuration for the mini toolbar on active view of a split.
+BASE_FEATURE_ENUM_PARAM(MiniToolbarActiveConfiguration,
+                        kSideBySideMiniToolbarActiveConfiguration,
+                        &kSideBySide,
+                        "mini_toolbar_active_config",
+                        MiniToolbarActiveConfiguration::Hide,
+                        &kMiniToolbarActiveConfigurationOptions);
+
 BASE_FEATURE(kSideBySideLinkMenuNewBadge,
              "SideBySideLinkMenuNewBadge",
              base::FEATURE_DISABLED_BY_DEFAULT);
@@ -159,7 +156,6 @@ BASE_FEATURE(kTabDuplicateMetrics,
 BASE_FEATURE(kTabScrollingButtonPosition,
              "TabScrollingButtonPosition",
              base::FEATURE_ENABLED_BY_DEFAULT);
-const char kTabScrollingButtonPositionParameterName[] = "buttonPosition";
 
 // Enables tabs to be frozen when collapsed.
 // https://crbug.com/1110108
@@ -178,16 +174,6 @@ BASE_FEATURE(kTabHoverCardImages,
 #endif
 );
 
-const char kTabHoverCardImagesNotReadyDelayParameterName[] =
-    "page_not_ready_delay";
-const char kTabHoverCardImagesLoadingDelayParameterName[] =
-    "page_loading_delay";
-const char kTabHoverCardImagesLoadedDelayParameterName[] = "page_loaded_delay";
-const char kTabHoverCardImagesCrossfadePreviewAtParameterName[] =
-    "crossfade_preview_at";
-const char kTabHoverCardAdditionalMaxWidthDelay[] =
-    "additional_max_width_delay";
-
 BASE_FEATURE(kTabOrganization,
              "TabOrganization",
              base::FEATURE_DISABLED_BY_DEFAULT);
@@ -200,16 +186,6 @@ BASE_FEATURE(kTabstripDeclutter,
              "TabstripDeclutter",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
-const base::FeatureParam<base::TimeDelta>
-    kTabstripDeclutterStaleThresholdDuration{
-        &kTabstripDeclutter, "stale_threshold_duration", base::Days(7)};
-
-const base::FeatureParam<base::TimeDelta> kTabstripDeclutterTimerInterval{
-    &kTabstripDeclutter, "declutter_timer_interval", base::Minutes(10)};
-
-const base::FeatureParam<base::TimeDelta> kTabstripDeclutterNudgeTimerInterval{
-    &kTabstripDeclutter, "nudge_timer_interval", base::Minutes(6 * 60)};
-
 bool IsTabstripDeclutterEnabled() {
   return base::FeatureList::IsEnabled(features::kTabstripDeclutter);
 }
@@ -239,21 +215,6 @@ BASE_FEATURE(kTabOrganizationEnableNudgeForEnterprise,
              "TabOrganizationEnableNudgeForEnterprise",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
-const base::FeatureParam<base::TimeDelta> kTabOrganizationTriggerPeriod{
-    &kTabOrganization, "trigger_period", base::Hours(6)};
-
-const base::FeatureParam<double> kTabOrganizationTriggerBackoffBase{
-    &kTabOrganization, "backoff_base", 2.0};
-
-const base::FeatureParam<double> kTabOrganizationTriggerThreshold{
-    &kTabOrganization, "trigger_threshold", 7.0};
-
-const base::FeatureParam<double> kTabOrganizationTriggerSensitivityThreshold{
-    &kTabOrganization, "trigger_sensitivity_threshold", 0.5};
-
-const base::FeatureParam<bool> KTabOrganizationTriggerDemoMode{
-    &kTabOrganization, "trigger_demo_mode", false};
-
 // Enables creating a web app window when tearing off a tab with a url
 // controlled by a web app.
 BASE_FEATURE(kTearOffWebAppTabOpensWebAppWindow,
@@ -277,7 +238,7 @@ BASE_FEATURE(kPinnedCastButton,
 // toolbar.
 BASE_FEATURE(kEnterpriseProfileBadgingForAvatar,
              "EnterpriseProfileBadgingForAvatar",
-             base::FEATURE_DISABLED_BY_DEFAULT);
+             base::FEATURE_ENABLED_BY_DEFAULT);
 
 // Enables enterprise profile badging for managed profiles on the toolbar avatar
 // and in the profile menu. On managed profiles, a building icon will be used as
@@ -367,7 +328,7 @@ BASE_FEATURE(kUsePortalAccentColor,
 
 BASE_FEATURE(kPageSpecificDataDialogRelatedInstalledAppsSection,
              "PageSpecificDataDialogRelatedInstalledAppsSection",
-             base::FEATURE_DISABLED_BY_DEFAULT);
+             base::FEATURE_ENABLED_BY_DEFAULT);
 
 BASE_FEATURE(kEnableManagementPromotionBanner,
              "EnableManagementPromotionBanner",
@@ -384,28 +345,6 @@ BASE_FEATURE(kInlineFullscreenPerfExperiment,
 BASE_FEATURE(kPageActionsMigration,
              "PageActionsMigration",
              base::FEATURE_DISABLED_BY_DEFAULT);
-const base::FeatureParam<bool> kPageActionsMigrationEnableAll{
-    &kPageActionsMigration, "enable_all", false};
-const base::FeatureParam<bool> kPageActionsMigrationLensOverlay{
-    &kPageActionsMigration, "lens_overlay", false};
-const base::FeatureParam<bool> kPageActionsMigrationMemorySaver{
-    &kPageActionsMigration, "memory_saver", false};
-const base::FeatureParam<bool> kPageActionsMigrationTranslate{
-    &kPageActionsMigration, "translate", false};
-const base::FeatureParam<bool> kPageActionsMigrationIntentPicker{
-    &kPageActionsMigration, "intent_picker", false};
-const base::FeatureParam<bool> kPageActionsMigrationZoom{&kPageActionsMigration,
-                                                         "zoom", false};
-const base::FeatureParam<bool> kPageActionsMigrationOfferNotification{
-    &kPageActionsMigration, "offer_notification", false};
-const base::FeatureParam<bool> kPageActionsMigrationFileSystemAccess{
-    &kPageActionsMigration, "file_system_access", false};
-const base::FeatureParam<bool> kPageActionsMigrationPwaInstall{
-    &kPageActionsMigration, "pwa_install", false};
-const base::FeatureParam<bool> kPageActionsMigrationPriceInsights{
-    &kPageActionsMigration, "price_insights", false};
-const base::FeatureParam<bool> kPageActionsMigrationManagePasswords{
-    &kPageActionsMigration, "manage_passwords", false};
 
 BASE_FEATURE(kSavePasswordsContextualUi,
              "SavePasswordsContextualUi",
@@ -436,15 +375,6 @@ BASE_FEATURE(kLaunchedTabSearchToolbarButton,
 #endif
 );
 
-const base::FeatureParam<bool> kTabstripComboButtonHasBackground{
-    &kTabstripComboButton, "has_background", false};
-
-const base::FeatureParam<bool> kTabstripComboButtonHasReverseButtonOrder{
-    &kTabstripComboButton, "reverse_button_order", false};
-
-const base::FeatureParam<bool> kTabSearchToolbarButton{
-    &kTabstripComboButton, "tab_search_toolbar_button", false};
-
 static std::string GetCountryCode() {
   if (!g_browser_process || !g_browser_process->variations_service()) {
     return std::string();
