@@ -420,8 +420,8 @@ void BookmarkMenuDelegate::ExecuteCommand(int id, int mouse_event_flags) {
   std::vector<raw_ptr<const BookmarkNode, VectorExperimental>> selection =
       menu_id_to_node_map_.find(id)->second.GetUnderlyingNodes(
           GetBookmarkMergedSurfaceService());
-  chrome::OpenAllIfAllowed(browser_, selection,
-                           ui::DispositionFromEventFlags(mouse_event_flags));
+  bookmarks::OpenAllIfAllowed(browser_, selection,
+                              ui::DispositionFromEventFlags(mouse_event_flags));
 }
 
 bool BookmarkMenuDelegate::ShouldExecuteCommandWithoutClosingMenu(
